import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { HttpClientModule } from '@angular/common/http';
import { Subject, of, BehaviorSubject } from 'rxjs';
import { NavigationEnd, Router, RouterModule } from '@angular/router';
import { NbAuthModule, NbDummyAuthStrategy, NbAuthComponent, NbLoginComponent, NbLogoutComponent, NbRegisterComponent, NbRequestPasswordComponent, NbResetPasswordComponent } from '@nebular/auth';
import { Location, CommonModule, APP_BASE_HREF } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { NbSecurityModule, NbRoleProvider } from '@nebular/security';
import { DomSanitizer, BrowserModule } from '@angular/platform-browser';
import { icons } from 'eva-icons';
import { Injectable, NgModule, Optional, SkipSelf, Component, Input, ElementRef, EventEmitter, Output, ViewChild, Pipe } from '@angular/core';
import { filter, delay, share, takeWhile, withLatestFrom } from 'rxjs/operators';
import { NbLayoutDirectionService, NbLayoutDirection, NbMenuService, NbSidebarService, NbThemeService, NbPopoverDirective, NbMediaBreakpointsService, NbActionsModule, NbCardModule, NbLayoutModule, NbMenuModule, NbRouteTabsetModule, NbSearchModule, NbSidebarModule, NbTabsetModule, NbThemeModule, NbUserModule, NbCheckboxModule, NbPopoverModule, NbContextMenuModule, NbProgressBarModule, NbCalendarModule, NbCalendarRangeModule, NbStepperModule, NbButtonModule, NbInputModule, NbAccordionModule, NbDatepickerModule, NbDialogModule, NbWindowModule, NbListModule, NbToastrModule, NbAlertModule, NbSpinnerModule, NbRadioModule, NbSelectModule, NbChatModule, NbTooltipModule, NbCalendarKitModule } from '@nebular/theme';
import { NgbModule } from '@ng-bootstrap/ng-bootstrap';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} parentModule
 * @param {?} moduleName
 * @return {?}
 */
function throwIfAlreadyLoaded(parentModule, moduleName) {
    if (parentModule) {
        throw new Error(`${moduleName} has already been loaded. Import Core modules in the AppModule only.`);
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AnalyticsService {
    /**
     * @param {?} location
     * @param {?} router
     */
    constructor(location, router) {
        this.location = location;
        this.router = router;
        this.enabled = false;
    }
    /**
     * @return {?}
     */
    trackPageViews() {
        if (this.enabled) {
            this.router.events.pipe(filter((event) => event instanceof NavigationEnd))
                .subscribe(() => {
                ga('send', { hitType: 'pageview', page: this.location.path() });
            });
        }
    }
    /**
     * @param {?} eventName
     * @return {?}
     */
    trackEvent(eventName) {
        if (this.enabled) {
            ga('send', 'event', eventName);
        }
    }
}
AnalyticsService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AnalyticsService.ctorParameters = () => [
    { type: Location },
    { type: Router }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LayoutService {
    constructor() {
        this.layoutSize$ = new Subject();
    }
    /**
     * @return {?}
     */
    changeLayoutSize() {
        this.layoutSize$.next();
    }
    /**
     * @return {?}
     */
    onChangeLayoutSize() {
        return this.layoutSize$.pipe(share(), delay(1));
    }
}
LayoutService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PlayerService {
    constructor() {
        this.playlist = [
            {
                name: 'Don\'t Wanna Fight',
                artist: 'Alabama Shakes',
                url: 'https://p.scdn.co/mp3-preview/6156cdbca425a894972c02fca9d76c0b70e001af',
                cover: 'assets/images/cover1.jpg',
            },
            {
                name: 'Harder',
                artist: 'Daft Punk',
                url: 'https://p.scdn.co/mp3-preview/92a04c7c0e96bf93a1b1b1cae7dfff1921969a7b',
                cover: 'assets/images/cover2.jpg',
            },
            {
                name: 'Come Together',
                artist: 'Beatles',
                url: 'https://p.scdn.co/mp3-preview/83090a4db6899eaca689ae35f69126dbe65d94c9',
                cover: 'assets/images/cover3.jpg',
            },
        ];
    }
    /**
     * @return {?}
     */
    random() {
        this.current = Math.floor(Math.random() * this.playlist.length);
        return this.playlist[this.current];
    }
    /**
     * @return {?}
     */
    next() {
        return this.getNextTrack();
    }
    /**
     * @return {?}
     */
    prev() {
        return this.getPrevTrack();
    }
    /**
     * @private
     * @return {?}
     */
    getNextTrack() {
        if (this.current === this.playlist.length - 1) {
            this.current = 0;
        }
        else {
            this.current++;
        }
        return this.playlist[this.current];
    }
    /**
     * @private
     * @return {?}
     */
    getPrevTrack() {
        if (this.current === 0) {
            this.current = this.playlist.length - 1;
        }
        else {
            this.current--;
        }
        return this.playlist[this.current];
    }
}
PlayerService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StateService {
    /**
     * @param {?} directionService
     */
    constructor(directionService) {
        this.layouts = [
            {
                name: 'One Column',
                icon: 'nb-layout-default',
                id: 'one-column',
                selected: true,
            },
            {
                name: 'Two Column',
                icon: 'nb-layout-two-column',
                id: 'two-column',
            },
            {
                name: 'Center Column',
                icon: 'nb-layout-centre',
                id: 'center-column',
            },
        ];
        this.sidebars = [
            {
                name: 'Sidebar at layout start',
                icon: 'nb-layout-sidebar-left',
                id: 'start',
                selected: true,
            },
            {
                name: 'Sidebar at layout end',
                icon: 'nb-layout-sidebar-right',
                id: 'end',
            },
        ];
        this.layoutState$ = new BehaviorSubject(this.layouts[0]);
        this.sidebarState$ = new BehaviorSubject(this.sidebars[0]);
        this.alive = true;
        directionService.onDirectionChange()
            .pipe(takeWhile(() => this.alive))
            .subscribe(direction => this.updateSidebarIcons(direction));
        this.updateSidebarIcons(directionService.getDirection());
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.alive = false;
    }
    /**
     * @private
     * @param {?} direction
     * @return {?}
     */
    updateSidebarIcons(direction) {
        const [startSidebar, endSidebar] = this.sidebars;
        /** @type {?} */
        const isLtr = direction === NbLayoutDirection.LTR;
        /** @type {?} */
        const startIconClass = isLtr ? 'nb-layout-sidebar-left' : 'nb-layout-sidebar-right';
        /** @type {?} */
        const endIconClass = isLtr ? 'nb-layout-sidebar-right' : 'nb-layout-sidebar-left';
        startSidebar.icon = startIconClass;
        endSidebar.icon = endIconClass;
    }
    /**
     * @param {?} state
     * @return {?}
     */
    setLayoutState(state) {
        this.layoutState$.next(state);
    }
    /**
     * @return {?}
     */
    getLayoutStates() {
        return of(this.layouts);
    }
    /**
     * @return {?}
     */
    onLayoutState() {
        return this.layoutState$.asObservable();
    }
    /**
     * @param {?} state
     * @return {?}
     */
    setSidebarState(state) {
        this.sidebarState$.next(state);
    }
    /**
     * @return {?}
     */
    getSidebarStates() {
        return of(this.sidebars);
    }
    /**
     * @return {?}
     */
    onSidebarState() {
        return this.sidebarState$.asObservable();
    }
}
StateService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
StateService.ctorParameters = () => [
    { type: NbLayoutDirectionService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class UserData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class ElectricityData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class SmartTableData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class UserActivityData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class OrdersChartData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class ProfitChartData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class TrafficListData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class EarningData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class OrdersProfitChartData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class TrafficBarData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class ProfitBarAnimationChartData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class TemperatureHumidityData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class SolarData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class TrafficChartData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class StatsBarData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class CountryOrderData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class StatsProgressBarData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class VisitorsAnalyticsData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class SecurityCamerasData {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UserService extends UserData {
    constructor() {
        super(...arguments);
        this.time = new Date;
        this.users = {
            nick: { name: 'Nick Jones', picture: 'assets/images/nick.png' },
            eva: { name: 'Eva Moor', picture: 'assets/images/eva.png' },
            jack: { name: 'Jack Williams', picture: 'assets/images/jack.png' },
            lee: { name: 'Lee Wong', picture: 'assets/images/lee.png' },
            alan: { name: 'Alan Thompson', picture: 'assets/images/alan.png' },
            kate: { name: 'Kate Martinez', picture: 'assets/images/kate.png' },
        };
        this.types = {
            mobile: 'mobile',
            home: 'home',
            work: 'work',
        };
        this.contacts = [
            { user: this.users.nick, type: this.types.mobile },
            { user: this.users.eva, type: this.types.home },
            { user: this.users.jack, type: this.types.mobile },
            { user: this.users.lee, type: this.types.mobile },
            { user: this.users.alan, type: this.types.home },
            { user: this.users.kate, type: this.types.work },
        ];
        this.recentUsers = [
            { user: this.users.alan, type: this.types.home, time: this.time.setHours(21, 12) },
            { user: this.users.eva, type: this.types.home, time: this.time.setHours(17, 45) },
            { user: this.users.nick, type: this.types.mobile, time: this.time.setHours(5, 29) },
            { user: this.users.lee, type: this.types.mobile, time: this.time.setHours(11, 24) },
            { user: this.users.jack, type: this.types.mobile, time: this.time.setHours(10, 45) },
            { user: this.users.kate, type: this.types.work, time: this.time.setHours(9, 42) },
            { user: this.users.kate, type: this.types.work, time: this.time.setHours(9, 31) },
            { user: this.users.jack, type: this.types.mobile, time: this.time.setHours(8, 0) },
        ];
    }
    /**
     * @return {?}
     */
    getUsers() {
        return of(this.users);
    }
    /**
     * @return {?}
     */
    getContacts() {
        return of(this.contacts);
    }
    /**
     * @return {?}
     */
    getRecentUsers() {
        return of(this.recentUsers);
    }
}
UserService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ElectricityService extends ElectricityData {
    constructor() {
        super();
        this.listData = [
            {
                title: '2015',
                months: [
                    { month: 'Jan', delta: '0.97', down: true, kWatts: '816', cost: '97' },
                    { month: 'Feb', delta: '1.83', down: true, kWatts: '806', cost: '95' },
                    { month: 'Mar', delta: '0.64', down: true, kWatts: '803', cost: '94' },
                    { month: 'Apr', delta: '2.17', down: false, kWatts: '818', cost: '98' },
                    { month: 'May', delta: '1.32', down: true, kWatts: '809', cost: '96' },
                    { month: 'Jun', delta: '0.05', down: true, kWatts: '808', cost: '96' },
                    { month: 'Jul', delta: '1.39', down: false, kWatts: '815', cost: '97' },
                    { month: 'Aug', delta: '0.73', down: true, kWatts: '807', cost: '95' },
                    { month: 'Sept', delta: '2.61', down: true, kWatts: '792', cost: '92' },
                    { month: 'Oct', delta: '0.16', down: true, kWatts: '791', cost: '92' },
                    { month: 'Nov', delta: '1.71', down: true, kWatts: '786', cost: '89' },
                    { month: 'Dec', delta: '0.37', down: false, kWatts: '789', cost: '91' },
                ],
            },
            {
                title: '2016',
                active: true,
                months: [
                    { month: 'Jan', delta: '1.56', down: true, kWatts: '789', cost: '91' },
                    { month: 'Feb', delta: '0.33', down: false, kWatts: '791', cost: '92' },
                    { month: 'Mar', delta: '0.62', down: true, kWatts: '790', cost: '92' },
                    { month: 'Apr', delta: '1.93', down: true, kWatts: '783', cost: '87' },
                    { month: 'May', delta: '2.52', down: true, kWatts: '771', cost: '83' },
                    { month: 'Jun', delta: '0.39', down: false, kWatts: '774', cost: '85' },
                    { month: 'Jul', delta: '1.61', down: true, kWatts: '767', cost: '81' },
                    { month: 'Aug', delta: '1.41', down: true, kWatts: '759', cost: '76' },
                    { month: 'Sept', delta: '1.03', down: true, kWatts: '752', cost: '74' },
                    { month: 'Oct', delta: '2.94', down: false, kWatts: '769', cost: '82' },
                    { month: 'Nov', delta: '0.26', down: true, kWatts: '767', cost: '81' },
                    { month: 'Dec', delta: '1.62', down: true, kWatts: '760', cost: '76' },
                ],
            },
            {
                title: '2017',
                months: [
                    { month: 'Jan', delta: '1.34', down: false, kWatts: '789', cost: '91' },
                    { month: 'Feb', delta: '0.95', down: false, kWatts: '793', cost: '93' },
                    { month: 'Mar', delta: '0.25', down: true, kWatts: '791', cost: '92' },
                    { month: 'Apr', delta: '1.72', down: false, kWatts: '797', cost: '95' },
                    { month: 'May', delta: '2.62', down: true, kWatts: '786', cost: '90' },
                    { month: 'Jun', delta: '0.72', down: false, kWatts: '789', cost: '91' },
                    { month: 'Jul', delta: '0.78', down: true, kWatts: '784', cost: '89' },
                    { month: 'Aug', delta: '0.36', down: true, kWatts: '782', cost: '88' },
                    { month: 'Sept', delta: '0.55', down: false, kWatts: '787', cost: '90' },
                    { month: 'Oct', delta: '1.81', down: true, kWatts: '779', cost: '86' },
                    { month: 'Nov', delta: '1.12', down: true, kWatts: '774', cost: '84' },
                    { month: 'Dec', delta: '0.52', down: false, kWatts: '776', cost: '95' },
                ],
            },
        ];
        this.chartPoints = [
            490, 490, 495, 500,
            505, 510, 520, 530,
            550, 580, 630, 720,
            800, 840, 860, 870,
            870, 860, 840, 800,
            720, 200, 145, 130,
            130, 145, 200, 570,
            635, 660, 670, 670,
            660, 630, 580, 460,
            380, 350, 340, 340,
            340, 340, 340, 340,
            340, 340, 340,
        ];
        this.chartData = this.chartPoints.map((p, index) => ({
            label: (index % 5 === 3) ? `${Math.round(index / 5)}` : '',
            value: p,
        }));
    }
    /**
     * @return {?}
     */
    getListData() {
        return of(this.listData);
    }
    /**
     * @return {?}
     */
    getChartData() {
        return of(this.chartData);
    }
}
ElectricityService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ElectricityService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SmartTableService extends SmartTableData {
    constructor() {
        super(...arguments);
        this.data = [{
                id: 1,
                firstName: 'Mark',
                lastName: 'Otto',
                username: '@mdo',
                email: 'mdo@gmail.com',
                age: '28',
            }, {
                id: 2,
                firstName: 'Jacob',
                lastName: 'Thornton',
                username: '@fat',
                email: 'fat@yandex.ru',
                age: '45',
            }, {
                id: 3,
                firstName: 'Larry',
                lastName: 'Bird',
                username: '@twitter',
                email: 'twitter@outlook.com',
                age: '18',
            }, {
                id: 4,
                firstName: 'John',
                lastName: 'Snow',
                username: '@snow',
                email: 'snow@gmail.com',
                age: '20',
            }, {
                id: 5,
                firstName: 'Jack',
                lastName: 'Sparrow',
                username: '@jack',
                email: 'jack@yandex.ru',
                age: '30',
            }, {
                id: 6,
                firstName: 'Ann',
                lastName: 'Smith',
                username: '@ann',
                email: 'ann@gmail.com',
                age: '21',
            }, {
                id: 7,
                firstName: 'Barbara',
                lastName: 'Black',
                username: '@barbara',
                email: 'barbara@yandex.ru',
                age: '43',
            }, {
                id: 8,
                firstName: 'Sevan',
                lastName: 'Bagrat',
                username: '@sevan',
                email: 'sevan@outlook.com',
                age: '13',
            }, {
                id: 9,
                firstName: 'Ruben',
                lastName: 'Vardan',
                username: '@ruben',
                email: 'ruben@gmail.com',
                age: '22',
            }, {
                id: 10,
                firstName: 'Karen',
                lastName: 'Sevan',
                username: '@karen',
                email: 'karen@yandex.ru',
                age: '33',
            }, {
                id: 11,
                firstName: 'Mark',
                lastName: 'Otto',
                username: '@mark',
                email: 'mark@gmail.com',
                age: '38',
            }, {
                id: 12,
                firstName: 'Jacob',
                lastName: 'Thornton',
                username: '@jacob',
                email: 'jacob@yandex.ru',
                age: '48',
            }, {
                id: 13,
                firstName: 'Haik',
                lastName: 'Hakob',
                username: '@haik',
                email: 'haik@outlook.com',
                age: '48',
            }, {
                id: 14,
                firstName: 'Garegin',
                lastName: 'Jirair',
                username: '@garegin',
                email: 'garegin@gmail.com',
                age: '40',
            }, {
                id: 15,
                firstName: 'Krikor',
                lastName: 'Bedros',
                username: '@krikor',
                email: 'krikor@yandex.ru',
                age: '32',
            }, {
                'id': 16,
                'firstName': 'Francisca',
                'lastName': 'Brady',
                'username': '@Gibson',
                'email': 'franciscagibson@comtours.com',
                'age': 11,
            }, {
                'id': 17,
                'firstName': 'Tillman',
                'lastName': 'Figueroa',
                'username': '@Snow',
                'email': 'tillmansnow@comtours.com',
                'age': 34,
            }, {
                'id': 18,
                'firstName': 'Jimenez',
                'lastName': 'Morris',
                'username': '@Bryant',
                'email': 'jimenezbryant@comtours.com',
                'age': 45,
            }, {
                'id': 19,
                'firstName': 'Sandoval',
                'lastName': 'Jacobson',
                'username': '@Mcbride',
                'email': 'sandovalmcbride@comtours.com',
                'age': 32,
            }, {
                'id': 20,
                'firstName': 'Griffin',
                'lastName': 'Torres',
                'username': '@Charles',
                'email': 'griffincharles@comtours.com',
                'age': 19,
            }, {
                'id': 21,
                'firstName': 'Cora',
                'lastName': 'Parker',
                'username': '@Caldwell',
                'email': 'coracaldwell@comtours.com',
                'age': 27,
            }, {
                'id': 22,
                'firstName': 'Cindy',
                'lastName': 'Bond',
                'username': '@Velez',
                'email': 'cindyvelez@comtours.com',
                'age': 24,
            }, {
                'id': 23,
                'firstName': 'Frieda',
                'lastName': 'Tyson',
                'username': '@Craig',
                'email': 'friedacraig@comtours.com',
                'age': 45,
            }, {
                'id': 24,
                'firstName': 'Cote',
                'lastName': 'Holcomb',
                'username': '@Rowe',
                'email': 'coterowe@comtours.com',
                'age': 20,
            }, {
                'id': 25,
                'firstName': 'Trujillo',
                'lastName': 'Mejia',
                'username': '@Valenzuela',
                'email': 'trujillovalenzuela@comtours.com',
                'age': 16,
            }, {
                'id': 26,
                'firstName': 'Pruitt',
                'lastName': 'Shepard',
                'username': '@Sloan',
                'email': 'pruittsloan@comtours.com',
                'age': 44,
            }, {
                'id': 27,
                'firstName': 'Sutton',
                'lastName': 'Ortega',
                'username': '@Black',
                'email': 'suttonblack@comtours.com',
                'age': 42,
            }, {
                'id': 28,
                'firstName': 'Marion',
                'lastName': 'Heath',
                'username': '@Espinoza',
                'email': 'marionespinoza@comtours.com',
                'age': 47,
            }, {
                'id': 29,
                'firstName': 'Newman',
                'lastName': 'Hicks',
                'username': '@Keith',
                'email': 'newmankeith@comtours.com',
                'age': 15,
            }, {
                'id': 30,
                'firstName': 'Boyle',
                'lastName': 'Larson',
                'username': '@Summers',
                'email': 'boylesummers@comtours.com',
                'age': 32,
            }, {
                'id': 31,
                'firstName': 'Haynes',
                'lastName': 'Vinson',
                'username': '@Mckenzie',
                'email': 'haynesmckenzie@comtours.com',
                'age': 15,
            }, {
                'id': 32,
                'firstName': 'Miller',
                'lastName': 'Acosta',
                'username': '@Young',
                'email': 'milleryoung@comtours.com',
                'age': 55,
            }, {
                'id': 33,
                'firstName': 'Johnston',
                'lastName': 'Brown',
                'username': '@Knight',
                'email': 'johnstonknight@comtours.com',
                'age': 29,
            }, {
                'id': 34,
                'firstName': 'Lena',
                'lastName': 'Pitts',
                'username': '@Forbes',
                'email': 'lenaforbes@comtours.com',
                'age': 25,
            }, {
                'id': 35,
                'firstName': 'Terrie',
                'lastName': 'Kennedy',
                'username': '@Branch',
                'email': 'terriebranch@comtours.com',
                'age': 37,
            }, {
                'id': 36,
                'firstName': 'Louise',
                'lastName': 'Aguirre',
                'username': '@Kirby',
                'email': 'louisekirby@comtours.com',
                'age': 44,
            }, {
                'id': 37,
                'firstName': 'David',
                'lastName': 'Patton',
                'username': '@Sanders',
                'email': 'davidsanders@comtours.com',
                'age': 26,
            }, {
                'id': 38,
                'firstName': 'Holden',
                'lastName': 'Barlow',
                'username': '@Mckinney',
                'email': 'holdenmckinney@comtours.com',
                'age': 11,
            }, {
                'id': 39,
                'firstName': 'Baker',
                'lastName': 'Rivera',
                'username': '@Montoya',
                'email': 'bakermontoya@comtours.com',
                'age': 47,
            }, {
                'id': 40,
                'firstName': 'Belinda',
                'lastName': 'Lloyd',
                'username': '@Calderon',
                'email': 'belindacalderon@comtours.com',
                'age': 21,
            }, {
                'id': 41,
                'firstName': 'Pearson',
                'lastName': 'Patrick',
                'username': '@Clements',
                'email': 'pearsonclements@comtours.com',
                'age': 42,
            }, {
                'id': 42,
                'firstName': 'Alyce',
                'lastName': 'Mckee',
                'username': '@Daugherty',
                'email': 'alycedaugherty@comtours.com',
                'age': 55,
            }, {
                'id': 43,
                'firstName': 'Valencia',
                'lastName': 'Spence',
                'username': '@Olsen',
                'email': 'valenciaolsen@comtours.com',
                'age': 20,
            }, {
                'id': 44,
                'firstName': 'Leach',
                'lastName': 'Holcomb',
                'username': '@Humphrey',
                'email': 'leachhumphrey@comtours.com',
                'age': 28,
            }, {
                'id': 45,
                'firstName': 'Moss',
                'lastName': 'Baxter',
                'username': '@Fitzpatrick',
                'email': 'mossfitzpatrick@comtours.com',
                'age': 51,
            }, {
                'id': 46,
                'firstName': 'Jeanne',
                'lastName': 'Cooke',
                'username': '@Ward',
                'email': 'jeanneward@comtours.com',
                'age': 59,
            }, {
                'id': 47,
                'firstName': 'Wilma',
                'lastName': 'Briggs',
                'username': '@Kidd',
                'email': 'wilmakidd@comtours.com',
                'age': 53,
            }, {
                'id': 48,
                'firstName': 'Beatrice',
                'lastName': 'Perry',
                'username': '@Gilbert',
                'email': 'beatricegilbert@comtours.com',
                'age': 39,
            }, {
                'id': 49,
                'firstName': 'Whitaker',
                'lastName': 'Hyde',
                'username': '@Mcdonald',
                'email': 'whitakermcdonald@comtours.com',
                'age': 35,
            }, {
                'id': 50,
                'firstName': 'Rebekah',
                'lastName': 'Duran',
                'username': '@Gross',
                'email': 'rebekahgross@comtours.com',
                'age': 40,
            }, {
                'id': 51,
                'firstName': 'Earline',
                'lastName': 'Mayer',
                'username': '@Woodward',
                'email': 'earlinewoodward@comtours.com',
                'age': 52,
            }, {
                'id': 52,
                'firstName': 'Moran',
                'lastName': 'Baxter',
                'username': '@Johns',
                'email': 'moranjohns@comtours.com',
                'age': 20,
            }, {
                'id': 53,
                'firstName': 'Nanette',
                'lastName': 'Hubbard',
                'username': '@Cooke',
                'email': 'nanettecooke@comtours.com',
                'age': 55,
            }, {
                'id': 54,
                'firstName': 'Dalton',
                'lastName': 'Walker',
                'username': '@Hendricks',
                'email': 'daltonhendricks@comtours.com',
                'age': 25,
            }, {
                'id': 55,
                'firstName': 'Bennett',
                'lastName': 'Blake',
                'username': '@Pena',
                'email': 'bennettpena@comtours.com',
                'age': 13,
            }, {
                'id': 56,
                'firstName': 'Kellie',
                'lastName': 'Horton',
                'username': '@Weiss',
                'email': 'kellieweiss@comtours.com',
                'age': 48,
            }, {
                'id': 57,
                'firstName': 'Hobbs',
                'lastName': 'Talley',
                'username': '@Sanford',
                'email': 'hobbssanford@comtours.com',
                'age': 28,
            }, {
                'id': 58,
                'firstName': 'Mcguire',
                'lastName': 'Donaldson',
                'username': '@Roman',
                'email': 'mcguireroman@comtours.com',
                'age': 38,
            }, {
                'id': 59,
                'firstName': 'Rodriquez',
                'lastName': 'Saunders',
                'username': '@Harper',
                'email': 'rodriquezharper@comtours.com',
                'age': 20,
            }, {
                'id': 60,
                'firstName': 'Lou',
                'lastName': 'Conner',
                'username': '@Sanchez',
                'email': 'lousanchez@comtours.com',
                'age': 16,
            }];
    }
    /**
     * @return {?}
     */
    getData() {
        return this.data;
    }
}
SmartTableService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PeriodsService {
    /**
     * @return {?}
     */
    getYears() {
        return [
            '2010', '2011', '2012',
            '2013', '2014', '2015',
            '2016', '2017', '2018',
        ];
    }
    /**
     * @return {?}
     */
    getMonths() {
        return [
            'Jan', 'Feb', 'Mar',
            'Apr', 'May', 'Jun',
            'Jul', 'Aug', 'Sep',
            'Oct', 'Nov', 'Dec',
        ];
    }
    /**
     * @return {?}
     */
    getWeeks() {
        return [
            'Mon',
            'Tue',
            'Wed',
            'Thu',
            'Fri',
            'Sat',
            'Sun',
        ];
    }
}
PeriodsService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UserActivityService extends UserActivityData {
    /**
     * @param {?} periods
     */
    constructor(periods) {
        super();
        this.periods = periods;
        this.getRandom = (roundTo) => Math.round(Math.random() * roundTo);
        this.data = {};
        this.data = {
            week: this.getDataWeek(),
            month: this.getDataMonth(),
            year: this.getDataYear(),
        };
    }
    /**
     * @private
     * @param {?} date
     * @return {?}
     */
    generateUserActivityRandomData(date) {
        return {
            date,
            pagesVisitCount: this.getRandom(1000),
            deltaUp: this.getRandom(1) % 2 === 0,
            newVisits: this.getRandom(100),
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataWeek() {
        return this.periods.getWeeks().map((week) => {
            return this.generateUserActivityRandomData(week);
        });
    }
    /**
     * @private
     * @return {?}
     */
    getDataMonth() {
        /** @type {?} */
        const currentDate = new Date();
        /** @type {?} */
        const days = currentDate.getDate();
        /** @type {?} */
        const month = this.periods.getMonths()[currentDate.getMonth()];
        return Array.from(Array(days)).map((_, index) => {
            /** @type {?} */
            const date = `${index + 1} ${month}`;
            return this.generateUserActivityRandomData(date);
        });
    }
    /**
     * @private
     * @return {?}
     */
    getDataYear() {
        return this.periods.getYears().map((year) => {
            return this.generateUserActivityRandomData(year);
        });
    }
    /**
     * @param {?} period
     * @return {?}
     */
    getUserActivityData(period) {
        return of(this.data[period]);
    }
}
UserActivityService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
UserActivityService.ctorParameters = () => [
    { type: PeriodsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OrdersChartService extends OrdersChartData {
    /**
     * @param {?} period
     */
    constructor(period) {
        super();
        this.period = period;
        this.year = [
            '2012',
            '2013',
            '2014',
            '2015',
            '2016',
            '2017',
            '2018',
        ];
        this.data = {};
        this.data = {
            week: this.getDataForWeekPeriod(),
            month: this.getDataForMonthPeriod(),
            year: this.getDataForYearPeriod(),
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataForWeekPeriod() {
        return {
            chartLabel: this.getDataLabels(42, this.period.getWeeks()),
            linesData: [
                [
                    184, 267, 326, 366, 389, 399,
                    392, 371, 340, 304, 265, 227,
                    191, 158, 130, 108, 95, 91, 97,
                    109, 125, 144, 166, 189, 212,
                    236, 259, 280, 300, 316, 329,
                    338, 342, 339, 329, 312, 288,
                    258, 221, 178, 128, 71,
                ],
                [
                    158, 178, 193, 205, 212, 213,
                    204, 190, 180, 173, 168, 164,
                    162, 160, 159, 158, 159, 166,
                    179, 195, 215, 236, 257, 276,
                    292, 301, 304, 303, 300, 293,
                    284, 273, 262, 251, 241, 234,
                    232, 232, 232, 232, 232, 232,
                ],
                [
                    58, 137, 202, 251, 288, 312,
                    323, 324, 311, 288, 257, 222,
                    187, 154, 124, 100, 81, 68, 61,
                    58, 61, 69, 80, 96, 115, 137,
                    161, 186, 210, 233, 254, 271,
                    284, 293, 297, 297, 297, 297,
                    297, 297, 297, 297, 297,
                ],
            ],
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataForMonthPeriod() {
        return {
            chartLabel: this.getDataLabels(47, this.period.getMonths()),
            linesData: [
                [
                    5, 63, 113, 156, 194, 225,
                    250, 270, 283, 289, 290,
                    286, 277, 264, 244, 220,
                    194, 171, 157, 151, 150,
                    152, 155, 160, 166, 170,
                    167, 153, 135, 115, 97,
                    82, 71, 64, 63, 62, 61,
                    62, 65, 73, 84, 102,
                    127, 159, 203, 259, 333,
                ],
                [
                    6, 83, 148, 200, 240,
                    265, 273, 259, 211,
                    122, 55, 30, 28, 36,
                    50, 68, 88, 109, 129,
                    146, 158, 163, 165,
                    173, 187, 208, 236,
                    271, 310, 346, 375,
                    393, 400, 398, 387,
                    368, 341, 309, 275,
                    243, 220, 206, 202,
                    207, 222, 247, 286, 348,
                ],
                [
                    398, 348, 315, 292, 274,
                    261, 251, 243, 237, 231,
                    222, 209, 192, 172, 152,
                    132, 116, 102, 90, 80, 71,
                    64, 58, 53, 49, 48, 54, 66,
                    84, 104, 125, 142, 156, 166,
                    172, 174, 172, 167, 159, 149,
                    136, 121, 105, 86, 67, 45, 22,
                ],
            ],
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataForYearPeriod() {
        return {
            chartLabel: this.getDataLabels(42, this.year),
            linesData: [
                [
                    190, 269, 327, 366, 389, 398,
                    396, 387, 375, 359, 343, 327,
                    312, 298, 286, 276, 270, 268,
                    265, 258, 247, 234, 220, 204,
                    188, 172, 157, 142, 128, 116,
                    106, 99, 95, 94, 92, 89, 84,
                    77, 69, 60, 49, 36, 22,
                ],
                [
                    265, 307, 337, 359, 375, 386,
                    393, 397, 399, 397, 390, 379,
                    365, 347, 326, 305, 282, 261,
                    241, 223, 208, 197, 190, 187,
                    185, 181, 172, 160, 145, 126,
                    105, 82, 60, 40, 26, 19, 22,
                    43, 82, 141, 220, 321,
                ],
                [
                    9, 165, 236, 258, 244, 206,
                    186, 189, 209, 239, 273, 307,
                    339, 365, 385, 396, 398, 385,
                    351, 300, 255, 221, 197, 181,
                    170, 164, 162, 161, 159, 154,
                    146, 135, 122, 108, 96, 87,
                    83, 82, 82, 82, 82, 82, 82,
                ],
            ],
        };
    }
    /**
     * @param {?} nPoints
     * @param {?} labelsArray
     * @return {?}
     */
    getDataLabels(nPoints, labelsArray) {
        /** @type {?} */
        const labelsArrayLength = labelsArray.length;
        /** @type {?} */
        const step = Math.round(nPoints / labelsArrayLength);
        return Array.from(Array(nPoints)).map((item, index) => {
            /** @type {?} */
            const dataIndex = Math.round(index / step);
            return index % step === 0 ? labelsArray[dataIndex] : '';
        });
    }
    /**
     * @param {?} period
     * @return {?}
     */
    getOrdersChartData(period) {
        return this.data[period];
    }
}
OrdersChartService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
OrdersChartService.ctorParameters = () => [
    { type: PeriodsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ProfitChartService extends ProfitChartData {
    /**
     * @param {?} period
     */
    constructor(period) {
        super();
        this.period = period;
        this.year = [
            '2012',
            '2013',
            '2014',
            '2015',
            '2016',
            '2017',
            '2018',
        ];
        this.data = {};
        this.data = {
            week: this.getDataForWeekPeriod(),
            month: this.getDataForMonthPeriod(),
            year: this.getDataForYearPeriod(),
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataForWeekPeriod() {
        /** @type {?} */
        const nPoint = this.period.getWeeks().length;
        return {
            chartLabel: this.period.getWeeks(),
            data: [
                this.getRandomData(nPoint),
                this.getRandomData(nPoint),
                this.getRandomData(nPoint),
            ],
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataForMonthPeriod() {
        /** @type {?} */
        const nPoint = this.period.getMonths().length;
        return {
            chartLabel: this.period.getMonths(),
            data: [
                this.getRandomData(nPoint),
                this.getRandomData(nPoint),
                this.getRandomData(nPoint),
            ],
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataForYearPeriod() {
        /** @type {?} */
        const nPoint = this.year.length;
        return {
            chartLabel: this.year,
            data: [
                this.getRandomData(nPoint),
                this.getRandomData(nPoint),
                this.getRandomData(nPoint),
            ],
        };
    }
    /**
     * @private
     * @param {?} nPoints
     * @return {?}
     */
    getRandomData(nPoints) {
        return Array.from(Array(nPoints)).map(() => {
            return Math.round(Math.random() * 500);
        });
    }
    /**
     * @param {?} period
     * @return {?}
     */
    getProfitChartData(period) {
        return this.data[period];
    }
}
ProfitChartService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ProfitChartService.ctorParameters = () => [
    { type: PeriodsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TrafficListService extends TrafficListData {
    /**
     * @param {?} period
     */
    constructor(period) {
        super();
        this.period = period;
        this.getRandom = (roundTo) => Math.round(Math.random() * roundTo);
        this.data = {};
        this.data = {
            week: this.getDataWeek(),
            month: this.getDataMonth(),
            year: this.getDataYear(),
        };
    }
    /**
     * @private
     * @return {?}
     */
    getDataWeek() {
        /** @type {?} */
        const getFirstDateInPeriod = () => {
            /** @type {?} */
            const weeks = this.period.getWeeks();
            return weeks[weeks.length - 1];
        };
        return this.reduceData(this.period.getWeeks(), getFirstDateInPeriod);
    }
    /**
     * @private
     * @return {?}
     */
    getDataMonth() {
        /** @type {?} */
        const getFirstDateInPeriod = () => {
            /** @type {?} */
            const months = this.period.getMonths();
            /** @type {?} */
            const date = new Date();
            /** @type {?} */
            const prevYear = date.getFullYear() - 1;
            return `${months[months.length - 1]}, ${prevYear}`;
        };
        return this.reduceData(this.period.getMonths(), getFirstDateInPeriod);
    }
    /**
     * @private
     * @return {?}
     */
    getDataYear() {
        /** @type {?} */
        const getFirstDateInPeriod = () => {
            /** @type {?} */
            const years = this.period.getYears();
            return `${parseInt(years[0], 10) - 1}`;
        };
        return this.reduceData(this.period.getYears(), getFirstDateInPeriod);
    }
    /**
     * @private
     * @param {?} timePeriods
     * @param {?} getFirstDateInPeriod
     * @return {?}
     */
    reduceData(timePeriods, getFirstDateInPeriod) {
        return timePeriods.reduce((result, timePeriod, index) => {
            /** @type {?} */
            const hasResult = result[index - 1];
            /** @type {?} */
            const prevDate = hasResult ?
                result[index - 1].comparison.nextDate :
                getFirstDateInPeriod();
            /** @type {?} */
            const prevValue = hasResult ?
                result[index - 1].comparison.nextValue :
                this.getRandom(100);
            /** @type {?} */
            const nextValue = this.getRandom(100);
            /** @type {?} */
            const deltaValue = prevValue - nextValue;
            /** @type {?} */
            const item = {
                date: timePeriod,
                value: this.getRandom(1000),
                delta: {
                    up: deltaValue <= 0,
                    value: Math.abs(deltaValue),
                },
                comparison: {
                    prevDate,
                    prevValue,
                    nextDate: timePeriod,
                    nextValue,
                },
            };
            return [...result, item];
        }, []);
    }
    /**
     * @param {?} period
     * @return {?}
     */
    getTrafficListData(period) {
        return of(this.data[period]);
    }
}
TrafficListService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TrafficListService.ctorParameters = () => [
    { type: PeriodsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EarningService extends EarningData {
    constructor() {
        super(...arguments);
        this.currentDate = new Date();
        this.currentValue = Math.random() * 1000;
        this.ONE_DAY = 24 * 3600 * 1000;
        this.pieChartData = [
            {
                value: 50,
                name: 'Bitcoin',
            },
            {
                value: 25,
                name: 'Tether',
            },
            {
                value: 25,
                name: 'Ethereum',
            },
        ];
        this.liveUpdateChartData = {
            bitcoin: {
                liveChart: [],
                delta: {
                    up: true,
                    value: 4,
                },
                dailyIncome: 45895,
            },
            tether: {
                liveChart: [],
                delta: {
                    up: false,
                    value: 9,
                },
                dailyIncome: 5862,
            },
            ethereum: {
                liveChart: [],
                delta: {
                    up: false,
                    value: 21,
                },
                dailyIncome: 584,
            },
        };
    }
    /**
     * @param {?} elementsNumber
     * @return {?}
     */
    getDefaultLiveChartData(elementsNumber) {
        this.currentDate = new Date();
        this.currentValue = Math.random() * 1000;
        return Array.from(Array(elementsNumber))
            .map(item => this.generateRandomLiveChartData());
    }
    /**
     * @return {?}
     */
    generateRandomLiveChartData() {
        this.currentDate = new Date(+this.currentDate + this.ONE_DAY);
        this.currentValue = this.currentValue + Math.random() * 20 - 11;
        if (this.currentValue < 0) {
            this.currentValue = Math.random() * 100;
        }
        return {
            value: [
                [
                    this.currentDate.getFullYear(),
                    this.currentDate.getMonth(),
                    this.currentDate.getDate(),
                ].join('/'),
                Math.round(this.currentValue),
            ],
        };
    }
    /**
     * @param {?} currency
     * @return {?}
     */
    getEarningLiveUpdateCardData(currency) {
        /** @type {?} */
        const data = this.liveUpdateChartData[currency.toLowerCase()];
        /** @type {?} */
        const newValue = this.generateRandomLiveChartData();
        data.liveChart.shift();
        data.liveChart.push(newValue);
        return of(data.liveChart);
    }
    /**
     * @param {?} currency
     * @return {?}
     */
    getEarningCardData(currency) {
        /** @type {?} */
        const data = this.liveUpdateChartData[currency.toLowerCase()];
        data.liveChart = this.getDefaultLiveChartData(150);
        return of(data);
    }
    /**
     * @return {?}
     */
    getEarningPieChartData() {
        return of(this.pieChartData);
    }
}
EarningService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OrdersProfitChartService extends OrdersProfitChartData {
    /**
     * @param {?} ordersChartService
     * @param {?} profitChartService
     */
    constructor(ordersChartService, profitChartService) {
        super();
        this.ordersChartService = ordersChartService;
        this.profitChartService = profitChartService;
        this.summary = [
            {
                title: 'Marketplace',
                value: 3654,
            },
            {
                title: 'Last Month',
                value: 946,
            },
            {
                title: 'Last Week',
                value: 654,
            },
            {
                title: 'Today',
                value: 230,
            },
        ];
    }
    /**
     * @return {?}
     */
    getOrderProfitChartSummary() {
        return of(this.summary);
    }
    /**
     * @param {?} period
     * @return {?}
     */
    getOrdersChartData(period) {
        return of(this.ordersChartService.getOrdersChartData(period));
    }
    /**
     * @param {?} period
     * @return {?}
     */
    getProfitChartData(period) {
        return of(this.profitChartService.getProfitChartData(period));
    }
}
OrdersProfitChartService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
OrdersProfitChartService.ctorParameters = () => [
    { type: OrdersChartData },
    { type: ProfitChartData }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TrafficBarService extends TrafficBarData {
    /**
     * @param {?} period
     */
    constructor(period) {
        super();
        this.period = period;
        this.data = {};
        this.data = {
            week: this.getDataForWeekPeriod(),
            month: this.getDataForMonthPeriod(),
            year: this.getDataForYearPeriod(),
        };
    }
    /**
     * @return {?}
     */
    getDataForWeekPeriod() {
        return {
            data: [10, 15, 19, 7, 20, 13, 15],
            labels: this.period.getWeeks(),
            formatter: '{c0} MB',
        };
    }
    /**
     * @return {?}
     */
    getDataForMonthPeriod() {
        return {
            data: [0.5, 0.3, 0.8, 0.2, 0.3, 0.7, 0.8, 1, 0.7, 0.8, 0.6, 0.7],
            labels: this.period.getMonths(),
            formatter: '{c0} GB',
        };
    }
    /**
     * @return {?}
     */
    getDataForYearPeriod() {
        return {
            data: [10, 15, 19, 7, 20, 13, 15, 19, 11],
            labels: this.period.getYears(),
            formatter: '{c0} GB',
        };
    }
    /**
     * @param {?} period
     * @return {?}
     */
    getTrafficBarData(period) {
        return of(this.data[period]);
    }
}
TrafficBarService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TrafficBarService.ctorParameters = () => [
    { type: PeriodsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ProfitBarAnimationChartService extends ProfitBarAnimationChartData {
    constructor() {
        super();
        this.data = {
            firstLine: this.getDataForFirstLine(),
            secondLine: this.getDataForSecondLine(),
        };
    }
    /**
     * @return {?}
     */
    getDataForFirstLine() {
        return this.createEmptyArray(100)
            .map((_, index) => {
            /** @type {?} */
            const oneFifth = index / 5;
            return (Math.sin(oneFifth) * (oneFifth - 10) + index / 6) * 5;
        });
    }
    /**
     * @return {?}
     */
    getDataForSecondLine() {
        return this.createEmptyArray(100)
            .map((_, index) => {
            /** @type {?} */
            const oneFifth = index / 5;
            return (Math.cos(oneFifth) * (oneFifth - 10) + index / 6) * 5;
        });
    }
    /**
     * @param {?} nPoints
     * @return {?}
     */
    createEmptyArray(nPoints) {
        return Array.from(Array(nPoints));
    }
    /**
     * @return {?}
     */
    getChartData() {
        return of(this.data);
    }
}
ProfitBarAnimationChartService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ProfitBarAnimationChartService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TemperatureHumidityService extends TemperatureHumidityData {
    constructor() {
        super(...arguments);
        this.temperatureDate = {
            value: 24,
            min: 12,
            max: 30,
        };
        this.humidityDate = {
            value: 87,
            min: 0,
            max: 100,
        };
    }
    /**
     * @return {?}
     */
    getTemperatureData() {
        return of(this.temperatureDate);
    }
    /**
     * @return {?}
     */
    getHumidityData() {
        return of(this.humidityDate);
    }
}
TemperatureHumidityService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SolarService extends SolarData {
    constructor() {
        super(...arguments);
        this.value = 42;
    }
    /**
     * @return {?}
     */
    getSolarData() {
        return of(this.value);
    }
}
SolarService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TrafficChartService extends TrafficChartData {
    constructor() {
        super(...arguments);
        this.data = [
            300, 520, 435, 530,
            730, 620, 660, 860,
        ];
    }
    /**
     * @return {?}
     */
    getTrafficChartData() {
        return of(this.data);
    }
}
TrafficChartService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StatsBarService extends StatsBarData {
    constructor() {
        super(...arguments);
        this.statsBarData = [
            300, 520, 435, 530,
            730, 620, 660, 860,
        ];
    }
    /**
     * @return {?}
     */
    getStatsBarData() {
        return of(this.statsBarData);
    }
}
StatsBarService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CountryOrderService extends CountryOrderData {
    constructor() {
        super(...arguments);
        this.countriesCategories = [
            'Sofas',
            'Furniture',
            'Lighting',
            'Tables',
            'Textiles',
        ];
        this.countriesCategoriesLength = this.countriesCategories.length;
    }
    /**
     * @private
     * @param {?} nPoints
     * @return {?}
     */
    generateRandomData(nPoints) {
        return Array.from(Array(nPoints)).map(() => {
            return Math.round(Math.random() * 20);
        });
    }
    /**
     * @return {?}
     */
    getCountriesCategories() {
        return of(this.countriesCategories);
    }
    /**
     * @param {?} country
     * @return {?}
     */
    getCountriesCategoriesData(country) {
        return of(this.generateRandomData(this.countriesCategoriesLength));
    }
}
CountryOrderService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StatsProgressBarService extends StatsProgressBarData {
    constructor() {
        super(...arguments);
        this.progressInfoData = [
            {
                title: 'Today’s Profit',
                value: 572900,
                activeProgress: 70,
                description: 'Better than last week (70%)',
            },
            {
                title: 'New Orders',
                value: 6378,
                activeProgress: 30,
                description: 'Better than last week (30%)',
            },
            {
                title: 'New Comments',
                value: 200,
                activeProgress: 55,
                description: 'Better than last week (55%)',
            },
        ];
    }
    /**
     * @return {?}
     */
    getProgressInfoData() {
        return of(this.progressInfoData);
    }
}
StatsProgressBarService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class VisitorsAnalyticsService extends VisitorsAnalyticsData {
    /**
     * @param {?} periodService
     */
    constructor(periodService) {
        super();
        this.periodService = periodService;
        this.pieChartValue = 75;
        this.innerLinePoints = [
            94, 188, 225, 244, 253, 254, 249, 235, 208,
            173, 141, 118, 105, 97, 94, 96, 104, 121, 147,
            183, 224, 265, 302, 333, 358, 375, 388, 395,
            400, 400, 397, 390, 377, 360, 338, 310, 278,
            241, 204, 166, 130, 98, 71, 49, 32, 20, 13, 9,
        ];
        this.outerLinePoints = [
            85, 71, 59, 50, 45, 42, 41, 44, 58, 88,
            136, 199, 267, 326, 367, 391, 400, 397,
            376, 319, 200, 104, 60, 41, 36, 37, 44,
            55, 74, 100, 131, 159, 180, 193, 199, 200,
            195, 184, 164, 135, 103, 73, 50, 33, 22, 15, 11,
        ];
    }
    /**
     * @private
     * @return {?}
     */
    generateOutlineLineData() {
        /** @type {?} */
        const months = this.periodService.getMonths();
        /** @type {?} */
        const outerLinePointsLength = this.outerLinePoints.length;
        /** @type {?} */
        const monthsLength = months.length;
        return this.outerLinePoints.map((p, index) => {
            /** @type {?} */
            const monthIndex = Math.round(index / 4);
            /** @type {?} */
            const label = (index % Math.round(outerLinePointsLength / monthsLength) === 0)
                ? months[monthIndex]
                : '';
            return {
                label,
                value: p,
            };
        });
    }
    /**
     * @return {?}
     */
    getInnerLineChartData() {
        return of(this.innerLinePoints);
    }
    /**
     * @return {?}
     */
    getOutlineLineChartData() {
        return of(this.generateOutlineLineData());
    }
    /**
     * @return {?}
     */
    getPieChartData() {
        return of(this.pieChartValue);
    }
}
VisitorsAnalyticsService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
VisitorsAnalyticsService.ctorParameters = () => [
    { type: PeriodsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SecurityCamerasService extends SecurityCamerasData {
    constructor() {
        super(...arguments);
        this.cameras = [
            {
                title: 'Camera #1',
                source: 'assets/images/camera1.jpg',
            },
            {
                title: 'Camera #2',
                source: 'assets/images/camera2.jpg',
            },
            {
                title: 'Camera #3',
                source: 'assets/images/camera3.jpg',
            },
            {
                title: 'Camera #4',
                source: 'assets/images/camera4.jpg',
            },
        ];
    }
    /**
     * @return {?}
     */
    getCamerasData() {
        return of(this.cameras);
    }
}
SecurityCamerasService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const SERVICES = [
    UserService,
    ElectricityService,
    SmartTableService,
    UserActivityService,
    OrdersChartService,
    ProfitChartService,
    TrafficListService,
    PeriodsService,
    EarningService,
    OrdersProfitChartService,
    TrafficBarService,
    ProfitBarAnimationChartService,
    TemperatureHumidityService,
    SolarService,
    TrafficChartService,
    StatsBarService,
    CountryOrderService,
    StatsProgressBarService,
    VisitorsAnalyticsService,
    SecurityCamerasService,
];
class MockDataModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return (/** @type {?} */ ({
            ngModule: MockDataModule,
            providers: [
                ...SERVICES,
            ],
        }));
    }
}
MockDataModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ],
                providers: [
                    ...SERVICES,
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const socialLinks = [
    {
        url: 'https://github.com/akveo/nebular',
        target: '_blank',
        icon: 'socicon-github',
    },
    {
        url: 'https://www.facebook.com/akveo/',
        target: '_blank',
        icon: 'socicon-facebook',
    },
    {
        url: 'https://twitter.com/akveo_inc',
        target: '_blank',
        icon: 'socicon-twitter',
    },
];
/** @type {?} */
const DATA_SERVICES = [
    { provide: UserData, useClass: UserService },
    { provide: ElectricityData, useClass: ElectricityService },
    { provide: SmartTableData, useClass: SmartTableService },
    { provide: UserActivityData, useClass: UserActivityService },
    { provide: OrdersChartData, useClass: OrdersChartService },
    { provide: ProfitChartData, useClass: ProfitChartService },
    { provide: TrafficListData, useClass: TrafficListService },
    { provide: EarningData, useClass: EarningService },
    { provide: OrdersProfitChartData, useClass: OrdersProfitChartService },
    { provide: TrafficBarData, useClass: TrafficBarService },
    { provide: ProfitBarAnimationChartData, useClass: ProfitBarAnimationChartService },
    { provide: TemperatureHumidityData, useClass: TemperatureHumidityService },
    { provide: SolarData, useClass: SolarService },
    { provide: TrafficChartData, useClass: TrafficChartService },
    { provide: StatsBarData, useClass: StatsBarService },
    { provide: CountryOrderData, useClass: CountryOrderService },
    { provide: StatsProgressBarData, useClass: StatsProgressBarService },
    { provide: VisitorsAnalyticsData, useClass: VisitorsAnalyticsService },
    { provide: SecurityCamerasData, useClass: SecurityCamerasService },
];
class NbSimpleRoleProvider extends NbRoleProvider {
    /**
     * @return {?}
     */
    getRole() {
        // here you could provide any role based on any auth flow
        return of('guest');
    }
}
/** @type {?} */
const NB_CORE_PROVIDERS = [
    ...MockDataModule.forRoot().providers,
    ...DATA_SERVICES,
    ...NbAuthModule.forRoot({
        strategies: [
            NbDummyAuthStrategy.setup({
                name: 'email',
                delay: 3000,
            }),
        ],
        forms: {
            login: {
                socialLinks: socialLinks,
            },
            register: {
                socialLinks: socialLinks,
            },
        },
    }).providers,
    NbSecurityModule.forRoot({
        accessControl: {
            guest: {
                view: '*',
            },
            user: {
                parent: 'guest',
                create: '*',
                edit: '*',
                remove: '*',
            },
        },
    }).providers,
    {
        provide: NbRoleProvider, useClass: NbSimpleRoleProvider,
    },
    AnalyticsService,
    LayoutService,
    PlayerService,
    StateService,
];
class CoreModule {
    /**
     * @param {?} parentModule
     */
    constructor(parentModule) {
        throwIfAlreadyLoaded(parentModule, 'CoreModule');
    }
    /**
     * @return {?}
     */
    static forRoot() {
        return (/** @type {?} */ ({
            ngModule: CoreModule,
            providers: [
                ...NB_CORE_PROVIDERS,
            ],
        }));
    }
}
CoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ],
                exports: [
                    NbAuthModule,
                ],
                declarations: [],
            },] }
];
/** @nocollapse */
CoreModule.ctorParameters = () => [
    { type: CoreModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AppComponent {
    /**
     * @param {?} analytics
     */
    constructor(analytics) {
        this.analytics = analytics;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.analytics.trackPageViews();
    }
}
AppComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-app',
                template: '<router-outlet></router-outlet>'
            }] }
];
/** @nocollapse */
AppComponent.ctorParameters = () => [
    { type: AnalyticsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const routes = [
    { path: 'pages', loadChildren: 'app/pages/pages.module#PagesModule' },
    {
        path: 'auth',
        component: NbAuthComponent,
        children: [
            {
                path: '',
                component: NbLoginComponent,
            },
            {
                path: 'login',
                component: NbLoginComponent,
            },
            {
                path: 'register',
                component: NbRegisterComponent,
            },
            {
                path: 'logout',
                component: NbLogoutComponent,
            },
            {
                path: 'request-password',
                component: NbRequestPasswordComponent,
            },
            {
                path: 'reset-password',
                component: NbResetPasswordComponent,
            },
        ],
    },
    { path: '', redirectTo: 'pages', pathMatch: 'full' },
    { path: '**', redirectTo: 'pages' },
];
/** @type {?} */
const config = {
    useHash: true,
};
class AppRoutingModule {
}
AppRoutingModule.decorators = [
    { type: NgModule, args: [{
                imports: [RouterModule.forRoot(routes, config)],
                exports: [RouterModule],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HeaderComponent {
    /**
     * @param {?} sidebarService
     * @param {?} menuService
     * @param {?} userService
     * @param {?} analyticsService
     * @param {?} layoutService
     */
    constructor(sidebarService, menuService, userService, analyticsService, layoutService) {
        this.sidebarService = sidebarService;
        this.menuService = menuService;
        this.userService = userService;
        this.analyticsService = analyticsService;
        this.layoutService = layoutService;
        this.position = 'normal';
        this.userMenu = [{ title: 'Profile' }, { title: 'Log out' }];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.userService.getUsers()
            .subscribe((users) => this.user = users.nick);
    }
    /**
     * @return {?}
     */
    toggleSidebar() {
        this.sidebarService.toggle(true, 'menu-sidebar');
        this.layoutService.changeLayoutSize();
        return false;
    }
    /**
     * @return {?}
     */
    goToHome() {
        this.menuService.navigateHome();
    }
    /**
     * @return {?}
     */
    startSearch() {
        this.analyticsService.trackEvent('startSearch');
    }
}
HeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-header',
                template: "<div class=\"header-container\"\n     [class.left]=\"position === 'normal'\"\n     [class.right]=\"position === 'inverse'\">\n  <div class=\"logo-containter\">\n    <a (click)=\"toggleSidebar()\" href=\"#\" class=\"navigation\"><i class=\"nb-menu\"></i></a>\n    <div class=\"logo\" (click)=\"goToHome()\">ngx-<span>admin</span></div>\n  </div>\n  <ngx-theme-switcher></ngx-theme-switcher>\n</div>\n\n<div class=\"header-container\">\n  <ngx-layout-direction-switcher></ngx-layout-direction-switcher>\n  <nb-actions\n    size=\"medium\"\n    [class.right]=\"position === 'normal'\"\n    [class.left]=\"position === 'inverse'\">\n    <nb-action *nbIsGranted=\"['view', 'user']\" >\n      <nb-user [nbContextMenu]=\"userMenu\" [name]=\"user?.name\" [picture]=\"user?.picture\"></nb-user>\n    </nb-action>\n    <nb-action class=\"control-item\" disabled icon=\"nb-notifications\"></nb-action>\n    <nb-action class=\"control-item\" icon=\"nb-email\"></nb-action>\n    <nb-action class=\"control-item\">\n      <nb-search type=\"rotate-layout\" (click)=\"startSearch()\"></nb-search>\n    </nb-action>\n  </nb-actions>\n</div>\n",
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;width:100%}.nb-theme-default :host .left{display:-webkit-box;display:-ms-flexbox;display:flex;width:100%;-webkit-box-ordinal-group:1;-ms-flex-order:0;order:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.nb-theme-default :host .right{-webkit-box-ordinal-group:2;-ms-flex-order:1;order:1;-webkit-box-orient:horizontal;-webkit-box-direction:reverse;-ms-flex-direction:row-reverse;flex-direction:row-reverse}.nb-theme-default :host .logo-containter{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:calc(16rem - 1.25rem)}.nb-theme-default :host .control-item{display:block}.nb-theme-default :host .header-container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:auto}.nb-theme-default :host .header-container .navigation{font-size:2.5rem;text-decoration:none}[dir=ltr] .nb-theme-default :host .header-container .navigation{padding-right:1.25rem}[dir=rtl] .nb-theme-default :host .header-container .navigation{padding-left:1.25rem}.nb-theme-default :host .header-container .navigation i{display:block}.nb-theme-default :host .header-container .logo{padding:0 1.25rem;font-size:1.75rem;font-weight:500;white-space:nowrap}[dir=ltr] .nb-theme-default :host .header-container .logo{border-left:1px solid #ebeef2}[dir=rtl] .nb-theme-default :host .header-container .logo{border-right:1px solid #ebeef2}.nb-theme-default :host .header-container .logo span{font-weight:400}.nb-theme-default :host ngx-layout-direction-switcher{margin:0 1.5rem}.nb-theme-default :host ngx-theme-switcher{margin:0 2.25rem}.nb-theme-default :host .toggle-settings /deep/ a{display:block;text-decoration:none;line-height:1}.nb-theme-default :host .toggle-settings /deep/ a i{color:#40dc7e;font-size:2.25rem;border-radius:50%;position:relative;-webkit-animation-name:pulse-light;animation-name:pulse-light}.nb-theme-default :host .toggle-settings /deep/ a i::after{content:' ';background-image:url(data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7);border-radius:50%;pointer-events:none;position:absolute;top:52.3%;left:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:13%;height:13%;-webkit-animation:3s linear infinite pulse-light;animation:3s linear infinite pulse-light}@-webkit-keyframes pulse{0%{-webkit-box-shadow:0 0 1px 0 rgba(64,220,126,0);box-shadow:0 0 1px 0 rgba(64,220,126,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(64,220,126,.4);box-shadow:0 0 3px 10px rgba(64,220,126,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(64,220,126,0);box-shadow:0 0 5px 20px rgba(64,220,126,0)}}@keyframes pulse{0%{-webkit-box-shadow:0 0 1px 0 rgba(64,220,126,0);box-shadow:0 0 1px 0 rgba(64,220,126,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(64,220,126,.4);box-shadow:0 0 3px 10px rgba(64,220,126,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(64,220,126,0);box-shadow:0 0 5px 20px rgba(64,220,126,0)}}@media (max-width:991.98px){.nb-theme-default :host nb-action:not(.toggle-settings){border:none}.nb-theme-default :host .control-item{display:none}.nb-theme-default :host .toggle-settings{padding:0}.nb-theme-default :host ngx-layout-direction-switcher{display:none}.nb-theme-default :host ngx-theme-switcher{margin:0 .5rem}}@media (max-width:767.98px){.nb-theme-default :host nb-user /deep/ .user-name{display:none}}@media (max-width:575.98px){.nb-theme-default :host .header-container .logo{font-size:1.25rem}.nb-theme-default :host .toggle-settings{display:none}.nb-theme-default :host ngx-theme-switcher{display:none}.nb-theme-default :host nb-action:not(.toggle-settings){padding:0}}@media (max-width:399.98px){.nb-theme-default :host .right /deep/{display:none}}.nb-theme-cosmic :host{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;width:100%}.nb-theme-cosmic :host .left{display:-webkit-box;display:-ms-flexbox;display:flex;width:100%;-webkit-box-ordinal-group:1;-ms-flex-order:0;order:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.nb-theme-cosmic :host .right{-webkit-box-ordinal-group:2;-ms-flex-order:1;order:1;-webkit-box-orient:horizontal;-webkit-box-direction:reverse;-ms-flex-direction:row-reverse;flex-direction:row-reverse}.nb-theme-cosmic :host .logo-containter{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:calc(16.25rem - 1.25rem)}.nb-theme-cosmic :host .control-item{display:block}.nb-theme-cosmic :host .header-container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:auto}.nb-theme-cosmic :host .header-container .navigation{font-size:2.5rem;text-decoration:none}[dir=ltr] .nb-theme-cosmic :host .header-container .navigation{padding-right:1.25rem}[dir=rtl] .nb-theme-cosmic :host .header-container .navigation{padding-left:1.25rem}.nb-theme-cosmic :host .header-container .navigation i{display:block}.nb-theme-cosmic :host .header-container .logo{padding:0 1.25rem;font-size:1.75rem;font-weight:500;white-space:nowrap}[dir=ltr] .nb-theme-cosmic :host .header-container .logo{border-left:1px solid #342e73}[dir=rtl] .nb-theme-cosmic :host .header-container .logo{border-right:1px solid #342e73}.nb-theme-cosmic :host .header-container .logo span{font-weight:400}.nb-theme-cosmic :host ngx-layout-direction-switcher{margin:0 1.5rem}.nb-theme-cosmic :host ngx-theme-switcher{margin:0 2.25rem}.nb-theme-cosmic :host .toggle-settings /deep/ a{display:block;text-decoration:none;line-height:1}.nb-theme-cosmic :host .toggle-settings /deep/ a i{color:#00f9a6;font-size:2.25rem;border-radius:50%;position:relative;-webkit-animation-name:pulse-light;animation-name:pulse-light}.nb-theme-cosmic :host .toggle-settings /deep/ a i::after{content:' ';background-image:url(data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7);border-radius:50%;pointer-events:none;position:absolute;top:52.3%;left:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:13%;height:13%;-webkit-animation:3s linear infinite pulse;animation:3s linear infinite pulse}@-webkit-keyframes pulse{0%{-webkit-box-shadow:0 0 1px 0 rgba(0,249,166,0);box-shadow:0 0 1px 0 rgba(0,249,166,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(0,249,166,.4);box-shadow:0 0 3px 10px rgba(0,249,166,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(0,249,166,0);box-shadow:0 0 5px 20px rgba(0,249,166,0)}}@keyframes pulse{0%{-webkit-box-shadow:0 0 1px 0 rgba(0,249,166,0);box-shadow:0 0 1px 0 rgba(0,249,166,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(0,249,166,.4);box-shadow:0 0 3px 10px rgba(0,249,166,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(0,249,166,0);box-shadow:0 0 5px 20px rgba(0,249,166,0)}}@media (max-width:991.98px){.nb-theme-cosmic :host nb-action:not(.toggle-settings){border:none}.nb-theme-cosmic :host .control-item{display:none}.nb-theme-cosmic :host .toggle-settings{padding:0}.nb-theme-cosmic :host ngx-layout-direction-switcher{display:none}.nb-theme-cosmic :host ngx-theme-switcher{margin:0 .5rem}}@media (max-width:767.98px){.nb-theme-cosmic :host nb-user /deep/ .user-name{display:none}}@media (max-width:575.98px){.nb-theme-cosmic :host .header-container .logo{font-size:1.25rem}.nb-theme-cosmic :host .toggle-settings{display:none}.nb-theme-cosmic :host ngx-theme-switcher{display:none}.nb-theme-cosmic :host nb-action:not(.toggle-settings){padding:0}}@media (max-width:399.98px){.nb-theme-cosmic :host .right /deep/{display:none}}.nb-theme-corporate :host{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;width:100%}.nb-theme-corporate :host .left{display:-webkit-box;display:-ms-flexbox;display:flex;width:100%;-webkit-box-ordinal-group:1;-ms-flex-order:0;order:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.nb-theme-corporate :host .right{-webkit-box-ordinal-group:2;-ms-flex-order:1;order:1;-webkit-box-orient:horizontal;-webkit-box-direction:reverse;-ms-flex-direction:row-reverse;flex-direction:row-reverse}.nb-theme-corporate :host .logo-containter{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:calc(16rem - 1.25rem)}.nb-theme-corporate :host .control-item{display:block}.nb-theme-corporate :host .header-container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:auto}.nb-theme-corporate :host .header-container .navigation{font-size:2.5rem;text-decoration:none}[dir=ltr] .nb-theme-corporate :host .header-container .navigation{padding-right:1.25rem}[dir=rtl] .nb-theme-corporate :host .header-container .navigation{padding-left:1.25rem}.nb-theme-corporate :host .header-container .navigation i{display:block}.nb-theme-corporate :host .header-container .logo{padding:0 1.25rem;font-size:1.75rem;font-weight:500;white-space:nowrap}[dir=ltr] .nb-theme-corporate :host .header-container .logo{border-left:1px solid #cdd5dc}[dir=rtl] .nb-theme-corporate :host .header-container .logo{border-right:1px solid #cdd5dc}.nb-theme-corporate :host .header-container .logo span{font-weight:400}[dir=ltr] .nb-theme-corporate :host nb-action{border-left-color:#3f4550}[dir=rtl] .nb-theme-corporate :host nb-action{border-right-color:#3f4550}[dir=ltr] .nb-theme-corporate :host .header-container .logo{border:none}[dir=rtl] .nb-theme-corporate :host .header-container .logo{border:none}.nb-theme-corporate :host .header-container /deep/ ngx-theme-switcher .dropdown-toggle{color:#fff;background:0 0}.nb-theme-corporate :host ngx-layout-direction-switcher{margin:0 1.5rem}.nb-theme-corporate :host ngx-theme-switcher{margin:0 2.25rem}@media (max-width:1399.98px){.nb-theme-default :host ngx-layout-direction-switcher{display:none}.nb-theme-cosmic :host ngx-layout-direction-switcher{display:none}.nb-theme-corporate :host ngx-layout-direction-switcher{display:none}}.nb-theme-corporate :host .toggle-settings /deep/ a{display:block;text-decoration:none;line-height:1}.nb-theme-corporate :host .toggle-settings /deep/ a i{color:#a4abb3;font-size:2.25rem;border-radius:50%;position:relative;-webkit-animation-name:pulse-light;animation-name:pulse-light}.nb-theme-corporate :host .toggle-settings /deep/ a i::after{content:' ';background-image:url(data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7);border-radius:50%;pointer-events:none;position:absolute;top:52.3%;left:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:13%;height:13%;-webkit-animation:3s linear infinite pulse;animation:3s linear infinite pulse}@-webkit-keyframes pulse{0%{-webkit-box-shadow:0 0 1px 0 rgba(164,171,179,0);box-shadow:0 0 1px 0 rgba(164,171,179,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(164,171,179,.4);box-shadow:0 0 3px 10px rgba(164,171,179,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(164,171,179,0);box-shadow:0 0 5px 20px rgba(164,171,179,0)}}@keyframes pulse{0%{-webkit-box-shadow:0 0 1px 0 rgba(164,171,179,0);box-shadow:0 0 1px 0 rgba(164,171,179,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(164,171,179,.4);box-shadow:0 0 3px 10px rgba(164,171,179,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(164,171,179,0);box-shadow:0 0 5px 20px rgba(164,171,179,0)}}@-webkit-keyframes pulse-light{0%{-webkit-box-shadow:0 0 1px 0 rgba(115,255,208,0);box-shadow:0 0 1px 0 rgba(115,255,208,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(115,255,208,.4);box-shadow:0 0 3px 10px rgba(115,255,208,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(115,255,208,0);box-shadow:0 0 5px 20px rgba(115,255,208,0)}}@keyframes pulse-light{0%{-webkit-box-shadow:0 0 1px 0 rgba(115,255,208,0);box-shadow:0 0 1px 0 rgba(115,255,208,0)}20%{-webkit-box-shadow:0 0 3px 10px rgba(115,255,208,.4);box-shadow:0 0 3px 10px rgba(115,255,208,.4)}100%{-webkit-box-shadow:0 0 5px 20px rgba(115,255,208,0);box-shadow:0 0 5px 20px rgba(115,255,208,0)}}@media (max-width:991.98px){.nb-theme-corporate :host nb-action:not(.toggle-settings){border:none}.nb-theme-corporate :host .control-item{display:none}.nb-theme-corporate :host .toggle-settings{padding:0}.nb-theme-corporate :host ngx-layout-direction-switcher{display:none}.nb-theme-corporate :host ngx-theme-switcher{margin:0 .5rem}}@media (max-width:767.98px){.nb-theme-corporate :host nb-user /deep/ .user-name{display:none}}@media (max-width:575.98px){.nb-theme-corporate :host .header-container .logo{font-size:1.25rem}.nb-theme-corporate :host .toggle-settings{display:none}.nb-theme-corporate :host ngx-theme-switcher{display:none}.nb-theme-corporate :host nb-action:not(.toggle-settings){padding:0}}@media (max-width:399.98px){.nb-theme-corporate :host .right /deep/{display:none}}"]
            }] }
];
/** @nocollapse */
HeaderComponent.ctorParameters = () => [
    { type: NbSidebarService },
    { type: NbMenuService },
    { type: UserData },
    { type: AnalyticsService },
    { type: LayoutService }
];
HeaderComponent.propDecorators = {
    position: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FooterComponent {
}
FooterComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-footer',
                template: `
    <span class="created-by">Created with ♥ by <b><a href="https://akveo.com" target="_blank">Akveo</a></b> 2017</span>
    <div class="socials">
      <a href="#" target="_blank" class="ion ion-social-github"></a>
      <a href="#" target="_blank" class="ion ion-social-facebook"></a>
      <a href="#" target="_blank" class="ion ion-social-twitter"></a>
      <a href="#" target="_blank" class="ion ion-social-linkedin"></a>
    </div>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.nb-theme-default :host .socials{font-size:2rem}.nb-theme-default :host .socials a{padding:.4rem;color:#a4abb3;-webkit-transition:color .1s ease-out;transition:color .1s ease-out}.nb-theme-default :host .socials a:hover{color:#2a2a2a}@media (max-width:575.98px){.nb-theme-default :host .socials{font-size:1.5rem}}.nb-theme-cosmic :host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.nb-theme-cosmic :host .socials{font-size:2rem}.nb-theme-cosmic :host .socials a{padding:.4rem;color:#a1a1e5;-webkit-transition:color .1s ease-out;transition:color .1s ease-out}.nb-theme-cosmic :host .socials a:hover{color:#fff}@media (max-width:575.98px){.nb-theme-cosmic :host .socials{font-size:1.5rem}}.nb-theme-corporate :host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.nb-theme-corporate :host .socials{font-size:2rem}.nb-theme-corporate :host .socials a{padding:.4rem;color:#a4abb3;-webkit-transition:color .1s ease-out;transition:color .1s ease-out}.nb-theme-corporate :host .socials a:hover{color:#181818}@media (max-width:575.98px){.nb-theme-corporate :host .socials{font-size:1.5rem}}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchInputComponent {
    constructor() {
        this.search = new EventEmitter();
        this.isInputShown = false;
    }
    /**
     * @return {?}
     */
    showInput() {
        this.isInputShown = true;
        this.input.nativeElement.focus();
    }
    /**
     * @return {?}
     */
    hideInput() {
        this.isInputShown = false;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    onInput(val) {
        this.search.emit(val);
    }
}
SearchInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-search-input',
                template: `
    <i class="control-icon ion ion-ios-search"
       (click)="showInput()"></i>
    <input placeholder="Type your search request here..."
           #input
           [class.hidden]="!isInputShown"
           (blur)="hideInput()"
           (input)="onInput($event)">
  `,
                styles: [":host{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}:host i.control-icon::before{font-size:2.3rem}:host i.control-icon:hover{cursor:pointer}:host input{border:none;outline:0;margin-left:1rem;width:15rem;-webkit-transition:width .2s;transition:width .2s}:host input.hidden{width:0;margin:0}:host /deep/ search-input input{background:0 0}"]
            }] }
];
SearchInputComponent.propDecorators = {
    input: [{ type: ViewChild, args: ['input',] }],
    search: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TinyMCEComponent {
    /**
     * @param {?} host
     */
    constructor(host) {
        this.host = host;
        this.editorKeyup = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        tinymce.init({
            target: this.host.nativeElement,
            plugins: ['link', 'paste', 'table'],
            skin_url: 'assets/skins/lightgray',
            setup: editor => {
                this.editor = editor;
                editor.on('keyup', () => {
                    this.editorKeyup.emit(editor.getContent());
                });
            },
            height: '320',
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        tinymce.remove(this.editor);
    }
}
TinyMCEComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-tiny-mce',
                template: ''
            }] }
];
/** @nocollapse */
TinyMCEComponent.ctorParameters = () => [
    { type: ElementRef }
];
TinyMCEComponent.propDecorators = {
    editorKeyup: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ThemeSettingsComponent {
    /**
     * @param {?} stateService
     */
    constructor(stateService) {
        this.stateService = stateService;
        this.layouts = [];
        this.sidebars = [];
        this.stateService.getLayoutStates()
            .subscribe((layouts) => this.layouts = layouts);
        this.stateService.getSidebarStates()
            .subscribe((sidebars) => this.sidebars = sidebars);
    }
    /**
     * @param {?} layout
     * @return {?}
     */
    layoutSelect(layout) {
        this.layouts = this.layouts.map((l) => {
            l.selected = false;
            return l;
        });
        layout.selected = true;
        this.stateService.setLayoutState(layout);
        return false;
    }
    /**
     * @param {?} sidebars
     * @return {?}
     */
    sidebarSelect(sidebars) {
        this.sidebars = this.sidebars.map((s) => {
            s.selected = false;
            return s;
        });
        sidebars.selected = true;
        this.stateService.setSidebarState(sidebars);
        return false;
    }
}
ThemeSettingsComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-theme-settings',
                template: `
    <h6>LAYOUTS</h6>
    <div class="settings-row">
      <a *ngFor="let layout of layouts"
         href="#"
         [class.selected]="layout.selected"
         [attr.title]="layout.name"
         (click)="layoutSelect(layout)">
        <i [attr.class]="layout.icon"></i>
      </a>
    </div>
    <h6>SIDEBAR</h6>
    <div class="settings-row">
      <a *ngFor="let sidebar of sidebars"
         href="#"
         [class.selected]="sidebar.selected"
         [attr.title]="sidebar.name"
         (click)="sidebarSelect(sidebar)">
        <i [attr.class]="sidebar.icon"></i>
      </a>
    </div>
    <div class="settings-row">
      <div class="switcher">
        <ngx-layout-direction-switcher></ngx-layout-direction-switcher>
      </div>
    </div>
  `,
                styles: [".nb-theme-default :host h6{margin-bottom:.875rem;text-align:center;font-weight:700;text-shadow:0 0 8px rgba(0,0,0,.16)}.nb-theme-default :host .settings-row{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;width:100%;margin:0 0 2.575rem}.nb-theme-default :host .settings-row a{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-line-pack:center;align-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:4.15rem;height:4.15rem;border-radius:.375rem;background-color:#fff;border:2px solid transparent;margin:.875rem;text-decoration:none;font-size:2.25rem;color:#a4abb3}.nb-theme-default :host .settings-row a.selected{color:#40dc7e;border-color:#40dc7e}.nb-theme-default :host .settings{margin-bottom:1em}.nb-theme-default :host .switcher{margin-bottom:1rem;font-size:1.524rem;width:12rem}.nb-theme-default :host .switcher /deep/ ngx-switcher .switch-label span{font-size:1em;font-weight:400}.nb-theme-default :host .switcher /deep/ ngx-switcher .switch-label span.first,.nb-theme-default :host .switcher /deep/ ngx-switcher .switch-label span.second{font-size:1rem}.nb-theme-default :host .switcher /deep/ ngx-switcher .switch{height:1.5em;width:3em}.nb-theme-default :host .switcher /deep/ ngx-switcher .switch .slider::before{height:1.5em;width:1.5em}[dir=ltr] .nb-theme-default :host .switcher /deep/ ngx-switcher .switch input:checked+.slider::before{-webkit-transform:translateX(1.5em)!important;transform:translateX(1.5em)!important}[dir=rtl] .nb-theme-default :host .switcher /deep/ ngx-switcher .switch input:checked+.slider::before{-webkit-transform:translateX(-1.5em)!important;transform:translateX(-1.5em)!important}.nb-theme-cosmic :host h6{margin-bottom:.875rem;text-align:center;font-weight:700;text-shadow:0 0 8px rgba(0,0,0,.16)}.nb-theme-cosmic :host .settings-row{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;width:100%;margin:0 0 2.575rem}.nb-theme-cosmic :host .settings-row a{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-line-pack:center;align-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:4.15rem;height:4.15rem;border-radius:.5rem;border:2px solid #3e367e;margin:.875rem;text-decoration:none;font-size:2.25rem;color:#a1a1e5;-webkit-box-shadow:0 4px 14px 0 rgba(19,19,94,.4);box-shadow:0 4px 14px 0 rgba(19,19,94,.4);background-color:#3e367e}.nb-theme-cosmic :host .settings-row a.selected{border-color:#00d977;color:#00f9a6}.nb-theme-cosmic :host .settings{margin-bottom:1em}.nb-theme-cosmic :host .switcher{margin-bottom:1rem;font-size:1.524rem;width:12rem}.nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch-label span{font-size:1em;font-weight:400}.nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch-label span.first,.nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch-label span.second{font-size:1rem}.nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch{height:1.5em;width:3em}.nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch .slider::before{height:1.5em;width:1.5em}[dir=ltr] .nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch input:checked+.slider::before{-webkit-transform:translateX(1.5em)!important;transform:translateX(1.5em)!important}[dir=rtl] .nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch input:checked+.slider::before{-webkit-transform:translateX(-1.5em)!important;transform:translateX(-1.5em)!important}.nb-theme-cosmic :host .switcher /deep/ ngx-switcher .switch .slider{background-color:#3d3780}.nb-theme-corporate :host h6{margin-bottom:.875rem;text-align:center;font-weight:700;text-shadow:0 0 8px rgba(0,0,0,.16)}.nb-theme-corporate :host .settings-row{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;width:100%;margin:0 0 2.575rem}.nb-theme-corporate :host .settings-row a{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-line-pack:center;align-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:4.15rem;height:4.15rem;border-radius:.17rem;background-color:#fff;border:2px solid transparent;margin:.875rem;text-decoration:none;font-size:2.25rem;color:#a4abb3}.nb-theme-corporate :host .settings-row a.selected{color:#5dcfe3;border-color:#5dcfe3}.nb-theme-corporate :host .settings{margin-bottom:1em}.nb-theme-corporate :host .switcher{margin-bottom:1rem;font-size:1.524rem;width:12rem}.nb-theme-corporate :host .switcher /deep/ ngx-switcher .switch-label span{font-size:1em;font-weight:400}.nb-theme-corporate :host .switcher /deep/ ngx-switcher .switch-label span.first,.nb-theme-corporate :host .switcher /deep/ ngx-switcher .switch-label span.second{font-size:1rem}.nb-theme-corporate :host .switcher /deep/ ngx-switcher .switch{height:1.5em;width:3em}.nb-theme-corporate :host .switcher /deep/ ngx-switcher .switch .slider::before{height:1.5em;width:1.5em}[dir=ltr] .nb-theme-corporate :host .switcher /deep/ ngx-switcher .switch input:checked+.slider::before{-webkit-transform:translateX(1.5em)!important;transform:translateX(1.5em)!important}[dir=rtl] .nb-theme-corporate :host .switcher /deep/ ngx-switcher .switch input:checked+.slider::before{-webkit-transform:translateX(-1.5em)!important;transform:translateX(-1.5em)!important}"]
            }] }
];
/** @nocollapse */
ThemeSettingsComponent.ctorParameters = () => [
    { type: StateService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ThemeSwitcherListComponent {
    /**
     * @param {?} themeService
     * @param {?} analyticsService
     */
    constructor(themeService, analyticsService) {
        this.themeService = themeService;
        this.analyticsService = analyticsService;
        this.themes = [
            {
                title: 'Light',
                key: 'default',
            },
            {
                title: 'Cosmic',
                key: 'cosmic',
            },
            {
                title: 'Corporate',
                key: 'corporate',
            },
        ];
    }
    /**
     * @param {?} themeKey
     * @return {?}
     */
    onToggleTheme(themeKey) {
        this.themeService.changeTheme(themeKey);
        this.analyticsService.trackEvent('switchTheme');
        this.popover.hide();
    }
}
ThemeSwitcherListComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-theme-switcher-list',
                template: `
    <ul class="themes-switcher-list">
      <li class="themes-switcher-item"
          *ngFor="let theme of themes"
          (click)="onToggleTheme(theme.key)">
        <i class="nb-drop" [ngClass]="'drop-icon-' + theme.key"></i>
        <span>{{ theme.title }}</span>
      </li>
    </ul>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host /deep/ .themes-switcher-list{padding:1rem 2rem 1.25rem .5rem;margin:0}[dir=ltr] .nb-theme-default :host /deep/ .themes-switcher-list{text-align:start}[dir=rtl] .nb-theme-default :host /deep/ .themes-switcher-list{text-align:end}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item{list-style:none;cursor:pointer}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item:hover span{opacity:.5}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item i{font-size:2rem}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-default{color:#0bbb79;background:-webkit-linear-gradient(#01dbb5,#0bbb79)}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-cosmic{color:#7958fa;background:-webkit-linear-gradient(#a258fe,#7958fa)}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-corporate{color:#a7a2be;background:-webkit-linear-gradient(#e9e8eb,#a7a2be)}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-corporate,.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-cosmic,.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-default{-webkit-background-clip:text;-webkit-text-fill-color:transparent}.nb-theme-default :host /deep/ .themes-switcher-list .themes-switcher-item span{font-weight:300;vertical-align:super;padding-left:1rem;color:#2a2a2a}.nb-theme-cosmic :host /deep/ .themes-switcher-list{padding:1rem 2rem 1.25rem .5rem;margin:0}[dir=ltr] .nb-theme-cosmic :host /deep/ .themes-switcher-list{text-align:start}[dir=rtl] .nb-theme-cosmic :host /deep/ .themes-switcher-list{text-align:end}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item{list-style:none;cursor:pointer}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item:hover span{opacity:.5}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item i{font-size:2rem}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-default{color:#0bbb79;background:-webkit-linear-gradient(#01dbb5,#0bbb79)}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-cosmic{color:#7958fa;background:-webkit-linear-gradient(#a258fe,#7958fa)}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-corporate{color:#a7a2be;background:-webkit-linear-gradient(#e9e8eb,#a7a2be)}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-corporate,.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-cosmic,.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-default{-webkit-background-clip:text;-webkit-text-fill-color:transparent}.nb-theme-cosmic :host /deep/ .themes-switcher-list .themes-switcher-item span{font-weight:300;vertical-align:super;padding-left:1rem;color:#fff}.nb-theme-corporate :host /deep/ .themes-switcher-list{padding:1rem 2rem 1.25rem .5rem;margin:0}[dir=ltr] .nb-theme-corporate :host /deep/ .themes-switcher-list{text-align:start}[dir=rtl] .nb-theme-corporate :host /deep/ .themes-switcher-list{text-align:end}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item{list-style:none;cursor:pointer}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item:hover span{opacity:.5}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item i{font-size:2rem}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-default{color:#0bbb79;background:-webkit-linear-gradient(#01dbb5,#0bbb79)}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-cosmic{color:#7958fa;background:-webkit-linear-gradient(#a258fe,#7958fa)}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-corporate{color:#a7a2be;background:-webkit-linear-gradient(#e9e8eb,#a7a2be)}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-corporate,.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-cosmic,.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item i.drop-icon-default{-webkit-background-clip:text;-webkit-text-fill-color:transparent}.nb-theme-corporate :host /deep/ .themes-switcher-list .themes-switcher-item span{font-weight:300;vertical-align:super;padding-left:1rem;color:#181818}@media (max-width:575.98px){.nb-theme-default :host /deep/ .themes-switcher-list{display:none}.nb-theme-cosmic :host /deep/ .themes-switcher-list{display:none}.nb-theme-corporate :host /deep/ .themes-switcher-list{display:none}}"]
            }] }
];
/** @nocollapse */
ThemeSwitcherListComponent.ctorParameters = () => [
    { type: NbThemeService },
    { type: AnalyticsService }
];
ThemeSwitcherListComponent.propDecorators = {
    popover: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ThemeSwitcherComponent {
    constructor() {
        this.showTitle = true;
        this.switcherListComponent = ThemeSwitcherListComponent;
    }
}
ThemeSwitcherComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-theme-switcher',
                template: "<div class=\"themes-switcher\"\n     [nbPopover]=\"switcherListComponent\"\n     nbPopoverPlacement=\"bottom\"\n     [nbPopoverContext]=\"{popover: popover}\">\n  <i class=\"nb-drops\"></i>\n  <span *ngIf=\"showTitle\">Themes</span>\n</div>\n",
                styles: [".nb-theme-default :host .themes-switcher{display:-webkit-box;display:-ms-flexbox;display:flex;font-size:1.25rem;padding:.8rem 1.25rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;background-color:#ebeff5;border-radius:.375rem}.nb-theme-default :host .themes-switcher:hover{background-color:#f5f7fa}.nb-theme-default :host .themes-switcher span{margin:0 1.2rem}.nb-theme-default :host .themes-switcher i{font-size:1.8rem;border-radius:50%;position:relative;color:#40dc7e}.nb-theme-default :host .themes-switcher i::before{background:-webkit-linear-gradient(#01dbb5,#0bbb79);-webkit-background-clip:text;-webkit-text-fill-color:transparent}.nb-theme-cosmic :host .themes-switcher{display:-webkit-box;display:-ms-flexbox;display:flex;font-size:1.25rem;padding:.8rem 1.25rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;background-color:#4e41a5;border-radius:.5rem}.nb-theme-cosmic :host .themes-switcher:hover{background-color:#675cb2}.nb-theme-cosmic :host .themes-switcher span{margin:0 1.2rem}.nb-theme-cosmic :host .themes-switcher i{color:#7659ff;font-size:1.8rem;border-radius:50%;position:relative}.nb-theme-cosmic :host .themes-switcher i::before{background:-webkit-linear-gradient(#a258fe,#7958fa);-webkit-background-clip:text;-webkit-text-fill-color:transparent}.nb-theme-corporate :host .themes-switcher{display:-webkit-box;display:-ms-flexbox;display:flex;font-size:1.25rem;padding:.8rem 1.25rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;background-color:#2b2d34;border-radius:.17rem}.nb-theme-corporate :host .themes-switcher:hover{background-color:#494a50}.nb-theme-corporate :host .themes-switcher span{margin:0 1.2rem}.nb-theme-corporate :host .themes-switcher i{font-size:1.8rem;border-radius:50%;position:relative;color:#a4abb3}.nb-theme-corporate :host .themes-switcher i::before{background:-webkit-linear-gradient(#e9e8eb,#a7a2be);-webkit-background-clip:text;-webkit-text-fill-color:transparent}"]
            }] }
];
ThemeSwitcherComponent.propDecorators = {
    popover: [{ type: ViewChild, args: [NbPopoverDirective,] }],
    showTitle: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SwitcherComponent {
    constructor() {
        this.valueChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    isFirstValue() {
        return this.value === this.firstValue;
    }
    /**
     * @return {?}
     */
    isSecondValue() {
        return this.value === this.secondValue;
    }
    /**
     * @return {?}
     */
    currentValueLabel() {
        return this.isFirstValue()
            ? this.firstValueLabel
            : this.secondValueLabel;
    }
    /**
     * @return {?}
     */
    changeValue() {
        this.value = this.isFirstValue()
            ? this.secondValue
            : this.firstValue;
        this.valueChange.emit(this.value);
    }
}
SwitcherComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-switcher',
                template: `
    <label class="switch-label" [class.vertical]="vertical">
      <span class="first" [class.active]="vertical || isFirstValue()">
        {{vertical ? currentValueLabel() : firstValueLabel}}
      </span>

      <div class="switch">
        <input type="checkbox" [checked]="isSecondValue()" (change)="changeValue()">
        <span class="slider"></span>
      </div>

      <span
        *ngIf="!vertical"
        class="second"
        [class.active]="isSecondValue()"
      >
          {{secondValueLabel}}
      </span>
    </label>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host .switch-label{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;margin:0}.nb-theme-default :host .switch-label.vertical{-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.nb-theme-default :host .switch-label.vertical .first,.nb-theme-default :host .switch-label.vertical .second{padding:0}.nb-theme-default :host .switch-label.vertical .switch{margin-top:.5em}.nb-theme-default :host .switch-label>span{font-size:1.125rem;font-weight:600;-webkit-transition:opacity .3s;transition:opacity .3s;color:#a4abb3}[dir=ltr] .nb-theme-default :host .switch-label>span.first{padding-right:10px}[dir=rtl] .nb-theme-default :host .switch-label>span.first{padding-left:10px}[dir=ltr] .nb-theme-default :host .switch-label>span.second{padding-left:10px}[dir=rtl] .nb-theme-default :host .switch-label>span.second{padding-right:10px}.nb-theme-default :host .switch-label>span.active{color:#4b4b4b}.nb-theme-default :host .switch-label>span:active{opacity:.78}.nb-theme-default :host .switch{position:relative;display:inline-block;width:3rem;height:1.5rem;margin:0}.nb-theme-default :host .switch input{display:none}[dir=ltr] .nb-theme-default :host .switch input:checked+.slider::before{-webkit-transform:translateX(1.5rem);transform:translateX(1.5rem)}[dir=rtl] .nb-theme-default :host .switch input:checked+.slider::before{-webkit-transform:translateX(-1.5rem);transform:translateX(-1.5rem)}.nb-theme-default :host .switch .slider{position:absolute;top:0;left:0;right:0;bottom:0;border-radius:1.75rem;background-color:#ebeff5}.nb-theme-default :host .switch .slider::before{position:absolute;content:'';height:1.5rem;width:1.5rem;border-radius:50%;background-color:#40dc7e;-webkit-transition:.2s;transition:.2s;-webkit-box-shadow:0 0 .25rem 0 rgba(164,171,179,.4);box-shadow:0 0 .25rem 0 rgba(164,171,179,.4)}@media (max-width:399.98px){.nb-theme-default :host{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}}.nb-theme-cosmic :host .switch-label{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;margin:0}.nb-theme-cosmic :host .switch-label.vertical{-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.nb-theme-cosmic :host .switch-label.vertical .first,.nb-theme-cosmic :host .switch-label.vertical .second{padding:0}.nb-theme-cosmic :host .switch-label.vertical .switch{margin-top:.5em}.nb-theme-cosmic :host .switch-label>span{font-size:1.125rem;font-weight:600;-webkit-transition:opacity .3s;transition:opacity .3s;color:#a1a1e5}[dir=ltr] .nb-theme-cosmic :host .switch-label>span.first{padding-right:10px}[dir=rtl] .nb-theme-cosmic :host .switch-label>span.first{padding-left:10px}[dir=ltr] .nb-theme-cosmic :host .switch-label>span.second{padding-left:10px}[dir=rtl] .nb-theme-cosmic :host .switch-label>span.second{padding-right:10px}.nb-theme-cosmic :host .switch-label>span.active{color:#fff}.nb-theme-cosmic :host .switch-label>span:active{opacity:.78}.nb-theme-cosmic :host .switch{position:relative;display:inline-block;width:3rem;height:1.5rem;margin:0}.nb-theme-cosmic :host .switch input{display:none}[dir=ltr] .nb-theme-cosmic :host .switch input:checked+.slider::before{-webkit-transform:translateX(1.5rem);transform:translateX(1.5rem)}[dir=rtl] .nb-theme-cosmic :host .switch input:checked+.slider::before{-webkit-transform:translateX(-1.5rem);transform:translateX(-1.5rem)}.nb-theme-cosmic :host .switch .slider{position:absolute;top:0;left:0;right:0;bottom:0;border-radius:1.75rem;background-color:#2f296b}.nb-theme-cosmic :host .switch .slider::before{position:absolute;content:'';height:1.5rem;width:1.5rem;border-radius:50%;background-color:#00d977;-webkit-transition:.2s;transition:.2s;-webkit-box-shadow:0 0 .25rem 0 rgba(161,161,229,.4);box-shadow:0 0 .25rem 0 rgba(161,161,229,.4);background-image:-webkit-gradient(linear,left top,right top,from(#ad59ff),to(#7659ff));background-image:linear-gradient(to right,#ad59ff,#7659ff)}@media (max-width:399.98px){.nb-theme-cosmic :host{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}}.nb-theme-corporate :host .switch-label{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;margin:0}.nb-theme-corporate :host .switch-label.vertical{-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.nb-theme-corporate :host .switch-label.vertical .first,.nb-theme-corporate :host .switch-label.vertical .second{padding:0}.nb-theme-corporate :host .switch-label.vertical .switch{margin-top:.5em}.nb-theme-corporate :host .switch-label>span{font-size:1.125rem;font-weight:600;-webkit-transition:opacity .3s;transition:opacity .3s;color:#a4abb3}[dir=ltr] .nb-theme-corporate :host .switch-label>span.first{padding-right:10px}[dir=rtl] .nb-theme-corporate :host .switch-label>span.first{padding-left:10px}[dir=ltr] .nb-theme-corporate :host .switch-label>span.second{padding-left:10px}[dir=rtl] .nb-theme-corporate :host .switch-label>span.second{padding-right:10px}.nb-theme-corporate :host .switch-label>span.active{color:#4b4b4b}.nb-theme-corporate :host .switch-label>span:active{opacity:.78}.nb-theme-corporate :host .switch{position:relative;display:inline-block;width:3rem;height:1.5rem;margin:0}.nb-theme-corporate :host .switch input{display:none}[dir=ltr] .nb-theme-corporate :host .switch input:checked+.slider::before{-webkit-transform:translateX(1.5rem);transform:translateX(1.5rem)}[dir=rtl] .nb-theme-corporate :host .switch input:checked+.slider::before{-webkit-transform:translateX(-1.5rem);transform:translateX(-1.5rem)}.nb-theme-corporate :host .switch .slider{position:absolute;top:0;left:0;right:0;bottom:0;border-radius:1.75rem;background-color:#f1f5f8}.nb-theme-corporate :host .switch .slider::before{position:absolute;content:'';height:1.5rem;width:1.5rem;border-radius:50%;-webkit-transition:.2s;transition:.2s;-webkit-box-shadow:0 0 .25rem 0 rgba(164,171,179,.4);box-shadow:0 0 .25rem 0 rgba(164,171,179,.4);background-color:#73a1ff}@media (max-width:399.98px){.nb-theme-corporate :host{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}}"]
            }] }
];
SwitcherComponent.propDecorators = {
    firstValue: [{ type: Input }],
    secondValue: [{ type: Input }],
    firstValueLabel: [{ type: Input }],
    secondValueLabel: [{ type: Input }],
    vertical: [{ type: Input }],
    value: [{ type: Input }],
    valueChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LayoutDirectionSwitcherComponent {
    /**
     * @param {?} directionService
     */
    constructor(directionService) {
        this.directionService = directionService;
        this.directions = NbLayoutDirection;
        this.alive = true;
        this.vertical = false;
        this.currentDirection = this.directionService.getDirection();
        this.directionService.onDirectionChange()
            .pipe(takeWhile(() => this.alive))
            .subscribe(newDirection => this.currentDirection = newDirection);
    }
    /**
     * @param {?} newDirection
     * @return {?}
     */
    toggleDirection(newDirection) {
        this.directionService.setDirection(newDirection);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.alive = false;
    }
}
LayoutDirectionSwitcherComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-layout-direction-switcher',
                template: `
    <ngx-switcher
      [firstValue]="directions.RTL"
      [secondValue]="directions.LTR"
      [firstValueLabel]="'RTL'"
      [secondValueLabel]="'LTR'"
      [value]="currentDirection"
      (valueChange)="toggleDirection($event)"
      [vertical]="vertical"
    >
    </ngx-switcher>
  `
            }] }
];
/** @nocollapse */
LayoutDirectionSwitcherComponent.ctorParameters = () => [
    { type: NbLayoutDirectionService }
];
LayoutDirectionSwitcherComponent.propDecorators = {
    vertical: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToggleSettingsButtonComponent {
    /**
     * @param {?} sidebarService
     * @param {?} stateService
     */
    constructor(sidebarService, stateService) {
        this.sidebarService = sidebarService;
        this.stateService = stateService;
        this.sidebarEnd = false;
        this.expanded = false;
        this.wasExpanded = false;
        this.stateService.onSidebarState()
            .subscribe(({ id }) => {
            this.sidebarEnd = id === 'end';
        });
    }
    /**
     * @return {?}
     */
    toggleSettings() {
        this.sidebarService.toggle(false, 'settings-sidebar');
        this.expanded = !this.expanded;
        this.wasExpanded = true;
    }
}
ToggleSettingsButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-toggle-settings-button',
                template: `
    <button class="toggle-settings"
            (click)="toggleSettings()"
            [class.expanded]="expanded"
            [class.sidebar-end]="sidebarEnd"
            [class.was-expanded]="wasExpanded"
    >
      <i class="nb-gear"></i>
    </button>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host .toggle-settings{position:fixed;top:50%;height:3rem;width:3rem;padding:0;text-align:center;border:1px solid #d5dbe0;-webkit-transition:background-image .3s,-webkit-transform .3s;transition:transform .3s,background-image .3s,-webkit-transform .3s;-webkit-transform:translate(0,-50%);transform:translate(0,-50%);z-index:998;-webkit-box-shadow:0 8px 24px 0 rgba(48,59,67,.15);box-shadow:0 8px 24px 0 rgba(48,59,67,.15);background-color:#fff}[dir=ltr] .nb-theme-default :host .toggle-settings{border-top-left-radius:.375rem;border-bottom-left-radius:.375rem;right:0}[dir=ltr] .nb-theme-default :host .toggle-settings.sidebar-end{right:auto;left:0;border-radius:0 .375rem .375rem 0}[dir=rtl] .nb-theme-default :host .toggle-settings{border-top-right-radius:.375rem;border-bottom-right-radius:.375rem;left:0}[dir=rtl] .nb-theme-default :host .toggle-settings.sidebar-end{left:auto;right:0;border-radius:.375rem 0 0 .375rem}[dir=ltr] .nb-theme-default :host .toggle-settings.expanded{-webkit-transform:translate(-19rem,-50%);transform:translate(-19rem,-50%)}[dir=rtl] .nb-theme-default :host .toggle-settings.expanded{-webkit-transform:translate(19rem,-50%);transform:translate(19rem,-50%)}[dir=rtl] .nb-theme-default :host .toggle-settings.expanded.sidebar-end{-webkit-transform:translate(-19rem,-50%);transform:translate(-19rem,-50%)}[dir=ltr] .nb-theme-default :host .toggle-settings.expanded.sidebar-end{-webkit-transform:translate(19rem,-50%);transform:translate(19rem,-50%)}.nb-theme-default :host .toggle-settings i{font-size:2.75rem;display:block;color:#ff4c6a}.nb-theme-default :host .toggle-settings:not(.was-expanded) i{-webkit-animation-name:gear-pulse;animation-name:gear-pulse;-webkit-animation-duration:1s;animation-duration:1s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite}@-webkit-keyframes gear-pulse{from,to{-webkit-transform:scale3d(1,1,1);transform:scale3d(1,1,1)}50%{-webkit-transform:scale3d(1.2,1.2,1.2);transform:scale3d(1.2,1.2,1.2)}}.nb-theme-cosmic :host .toggle-settings{position:fixed;top:50%;height:3rem;width:3rem;padding:0;text-align:center;border:none;-webkit-transition:background-image .3s,-webkit-transform .3s;transition:transform .3s,background-image .3s,-webkit-transform .3s;-webkit-transform:translate(0,-50%);transform:translate(0,-50%);z-index:998;-webkit-box-shadow:0 0 3.4285rem 0 rgba(19,19,94,.72);box-shadow:0 0 3.4285rem 0 rgba(19,19,94,.72);background-image:-webkit-gradient(linear,left top,right top,from(#00d9bf),to(#00d977));background-image:linear-gradient(to right,#00d9bf,#00d977)}[dir=ltr] .nb-theme-cosmic :host .toggle-settings{border-top-left-radius:.5rem;border-bottom-left-radius:.5rem;right:0}[dir=ltr] .nb-theme-cosmic :host .toggle-settings.sidebar-end{right:auto;left:0;border-radius:0 .5rem .5rem 0}[dir=rtl] .nb-theme-cosmic :host .toggle-settings{border-top-right-radius:.5rem;border-bottom-right-radius:.5rem;left:0}[dir=rtl] .nb-theme-cosmic :host .toggle-settings.sidebar-end{left:auto;right:0;border-radius:.5rem 0 0 .5rem}[dir=ltr] .nb-theme-cosmic :host .toggle-settings.expanded{-webkit-transform:translate(-19rem,-50%);transform:translate(-19rem,-50%)}[dir=rtl] .nb-theme-cosmic :host .toggle-settings.expanded{-webkit-transform:translate(19rem,-50%);transform:translate(19rem,-50%)}[dir=rtl] .nb-theme-cosmic :host .toggle-settings.expanded.sidebar-end{-webkit-transform:translate(-19rem,-50%);transform:translate(-19rem,-50%)}[dir=ltr] .nb-theme-cosmic :host .toggle-settings.expanded.sidebar-end{-webkit-transform:translate(19rem,-50%);transform:translate(19rem,-50%)}.nb-theme-cosmic :host .toggle-settings i{font-size:2.75rem;color:#fff;display:block}.nb-theme-cosmic :host .toggle-settings:not(.was-expanded) i{-webkit-animation-name:gear-pulse;animation-name:gear-pulse;-webkit-animation-duration:1s;animation-duration:1s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite}.nb-theme-corporate :host .toggle-settings{position:fixed;top:50%;height:3rem;width:3rem;padding:0;text-align:center;border:1px solid #d5dbe0;-webkit-transition:background-image .3s,-webkit-transform .3s;transition:transform .3s,background-image .3s,-webkit-transform .3s;-webkit-transform:translate(0,-50%);transform:translate(0,-50%);z-index:998;-webkit-box-shadow:0 8px 24px 0 rgba(48,59,67,.15);box-shadow:0 8px 24px 0 rgba(48,59,67,.15);color:#ff6b83;background-color:#fff}[dir=ltr] .nb-theme-corporate :host .toggle-settings{border-top-left-radius:.17rem;border-bottom-left-radius:.17rem;right:0}[dir=ltr] .nb-theme-corporate :host .toggle-settings.sidebar-end{right:auto;left:0;border-radius:0 .17rem .17rem 0}[dir=rtl] .nb-theme-corporate :host .toggle-settings{border-top-right-radius:.17rem;border-bottom-right-radius:.17rem;left:0}[dir=rtl] .nb-theme-corporate :host .toggle-settings.sidebar-end{left:auto;right:0;border-radius:.17rem 0 0 .17rem}[dir=ltr] .nb-theme-corporate :host .toggle-settings.expanded{-webkit-transform:translate(-19rem,-50%);transform:translate(-19rem,-50%)}[dir=rtl] .nb-theme-corporate :host .toggle-settings.expanded{-webkit-transform:translate(19rem,-50%);transform:translate(19rem,-50%)}[dir=rtl] .nb-theme-corporate :host .toggle-settings.expanded.sidebar-end{-webkit-transform:translate(-19rem,-50%);transform:translate(-19rem,-50%)}[dir=ltr] .nb-theme-corporate :host .toggle-settings.expanded.sidebar-end{-webkit-transform:translate(19rem,-50%);transform:translate(19rem,-50%)}.nb-theme-corporate :host .toggle-settings i{font-size:2.75rem;display:block;color:#ffa36b}.nb-theme-corporate :host .toggle-settings:not(.was-expanded) i{-webkit-animation-name:gear-pulse;animation-name:gear-pulse;-webkit-animation-duration:1s;animation-duration:1s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite}@keyframes gear-pulse{from,to{-webkit-transform:scale3d(1,1,1);transform:scale3d(1,1,1)}50%{-webkit-transform:scale3d(1.2,1.2,1.2);transform:scale3d(1.2,1.2,1.2)}}@media (max-width:767.98px){.nb-theme-default :host .toggle-settings{display:none}.nb-theme-cosmic :host .toggle-settings{display:none}.nb-theme-corporate :host .toggle-settings{display:none}}"]
            }] }
];
/** @nocollapse */
ToggleSettingsButtonComponent.ctorParameters = () => [
    { type: NbSidebarService },
    { type: StateService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CapitalizePipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return input && input.length
            ? (input.charAt(0).toUpperCase() + input.slice(1).toLowerCase())
            : input;
    }
}
CapitalizePipe.decorators = [
    { type: Pipe, args: [{ name: 'ngxCapitalize' },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PluralPipe {
    /**
     * @param {?} input
     * @param {?} label
     * @param {?=} pluralLabel
     * @return {?}
     */
    transform(input, label, pluralLabel = '') {
        input = input || 0;
        return input === 1
            ? `${input} ${label}`
            : pluralLabel
                ? `${input} ${pluralLabel}`
                : `${input} ${label}s`;
    }
}
PluralPipe.decorators = [
    { type: Pipe, args: [{ name: 'ngxPlural' },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RoundPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return Math.round(input);
    }
}
RoundPipe.decorators = [
    { type: Pipe, args: [{ name: 'ngxRound' },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TimingPipe {
    /**
     * @param {?} time
     * @return {?}
     */
    transform(time) {
        if (time) {
            /** @type {?} */
            const minutes = Math.floor(time / 60);
            /** @type {?} */
            const seconds = Math.floor(time % 60);
            return `${this.initZero(minutes)}${minutes}:${this.initZero(seconds)}${seconds}`;
        }
        return '00:00';
    }
    /**
     * @private
     * @param {?} time
     * @return {?}
     */
    initZero(time) {
        return time < 10 ? '0' : '';
    }
}
TimingPipe.decorators = [
    { type: Pipe, args: [{ name: 'timing' },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NumberWithCommasPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return new Intl.NumberFormat().format(input);
    }
}
NumberWithCommasPipe.decorators = [
    { type: Pipe, args: [{ name: 'ngxNumberWithCommas' },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EvaIconsPipe {
    /**
     * @param {?} sanitizer
     */
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.defaultOptions = {
            height: 24,
            width: 24,
            fill: 'inherit',
            animationHover: true,
            animationInfinity: false,
        };
    }
    /**
     * @param {?} icon
     * @param {?} options
     * @return {?}
     */
    transform(icon, options) {
        /** @type {?} */
        const mergedOptions = Object.assign({}, this.defaultOptions, options);
        const { width, height, fill, animationType, animationHover, animationInfinity } = mergedOptions;
        /** @type {?} */
        const animation = animationType ?
            { type: animationType, hover: animationHover, infinite: animationInfinity } :
            null;
        return this.sanitizer.bypassSecurityTrustHtml(icons[icon].toSvg({
            width,
            height,
            fill,
            animation,
        }));
    }
}
EvaIconsPipe.decorators = [
    { type: Pipe, args: [{ name: 'eva' },] }
];
/** @nocollapse */
EvaIconsPipe.ctorParameters = () => [
    { type: DomSanitizer }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// TODO: move layouts into the framework
class OneColumnLayoutComponent {
    /**
     * @param {?} themeService
     */
    constructor(themeService) {
        this.themeService = themeService;
        this.alive = true;
        this.themeService.getJsTheme()
            .pipe(takeWhile(() => this.alive))
            .subscribe(theme => {
            this.currentTheme = theme.name;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.alive = false;
    }
}
OneColumnLayoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-one-column-layout',
                template: `
    <nb-layout>
      <nb-layout-header fixed>
        <ngx-header></ngx-header>
      </nb-layout-header>

      <nb-sidebar class="menu-sidebar" tag="menu-sidebar" responsive>
        <nb-sidebar-header *ngIf="currentTheme !== 'corporate'">
          <a href="#" class="btn btn-hero-success main-btn">
            <i class="ion ion-social-github"></i> <span>Support Us</span>
          </a>
        </nb-sidebar-header>
        <ng-content select="nb-menu"></ng-content>
      </nb-sidebar>

      <nb-layout-column>
        <ng-content select="router-outlet"></ng-content>
      </nb-layout-column>

      <nb-layout-footer fixed>
        <ngx-footer></ngx-footer>
      </nb-layout-footer>
    </nb-layout>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-default :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#fff;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.375rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.375rem}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-default :host .main-btn{display:none}}.nb-theme-cosmic :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-cosmic :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#2f296b;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.5rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.5rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-cosmic :host .main-btn{display:none}}.nb-theme-corporate :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-corporate :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#fff;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0;background:0 0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border:1px solid #cdd5dc;height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.17rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable{padding-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable .menu-item:first-child{border-top:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48);border-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:399.98px){.nb-theme-default :host .main-content{padding:.75rem!important}.nb-theme-cosmic :host .main-content{padding:.75rem!important}.nb-theme-corporate :host .main-content{padding:.75rem!important}}@media (max-width:767.98px){.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-corporate :host .main-btn{display:none}}"]
            }] }
];
/** @nocollapse */
OneColumnLayoutComponent.ctorParameters = () => [
    { type: NbThemeService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// TODO: move layouts into the framework
class TwoColumnsLayoutComponent {
    /**
     * @param {?} themeService
     */
    constructor(themeService) {
        this.themeService = themeService;
        this.alive = true;
        this.themeService.getJsTheme()
            .pipe(takeWhile(() => this.alive))
            .subscribe(theme => {
            this.currentTheme = theme.name;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.alive = false;
    }
}
TwoColumnsLayoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-two-columns-layout',
                template: `
    <nb-layout>
      <nb-layout-header fixed>
        <ngx-header></ngx-header>
      </nb-layout-header>

      <nb-sidebar class="menu-sidebar" tag="menu-sidebar" responsive >
        <nb-sidebar-header *ngIf="currentTheme !== 'corporate'">
          <a href="#" class="btn btn-hero-success main-btn">
            <i class="ion ion-social-github"></i> <span>Support Us</span>
          </a>
        </nb-sidebar-header>
        <ng-content select="nb-menu"></ng-content>
      </nb-sidebar>

      <nb-layout-column class="small">
      </nb-layout-column>

      <nb-layout-column>
        <ng-content select="router-outlet"></ng-content>
      </nb-layout-column>

      <nb-layout-footer fixed>
        <ngx-footer></ngx-footer>
      </nb-layout-footer>

    </nb-layout>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-default :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#fff;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.375rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.375rem}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-default :host .main-btn{display:none}}.nb-theme-cosmic :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-cosmic :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#2f296b;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.5rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.5rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-cosmic :host .main-btn{display:none}}.nb-theme-corporate :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-corporate :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#fff;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0;background:0 0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border:1px solid #cdd5dc;height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.17rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable{padding-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable .menu-item:first-child{border-top:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48);border-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:399.98px){.nb-theme-default :host .main-content{padding:.75rem!important}.nb-theme-cosmic :host .main-content{padding:.75rem!important}.nb-theme-corporate :host .main-content{padding:.75rem!important}}@media (max-width:767.98px){.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-corporate :host .main-btn{display:none}}"]
            }] }
];
/** @nocollapse */
TwoColumnsLayoutComponent.ctorParameters = () => [
    { type: NbThemeService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// TODO: move layouts into the framework
class ThreeColumnsLayoutComponent {
    /**
     * @param {?} themeService
     */
    constructor(themeService) {
        this.themeService = themeService;
        this.alive = true;
        this.themeService.getJsTheme()
            .pipe(takeWhile(() => this.alive))
            .subscribe(theme => {
            this.currentTheme = theme.name;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.alive = false;
    }
}
ThreeColumnsLayoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-three-columns-layout',
                template: `
    <nb-layout>
      <nb-layout-header fixed>
        <ngx-header></ngx-header>
      </nb-layout-header>

      <nb-sidebar class="menu-sidebar" tag="menu-sidebar" responsive >
        <nb-sidebar-header *ngIf="currentTheme !== 'corporate'">
          <a href="#" class="btn btn-hero-success main-btn">
            <i class="ion ion-social-github"></i> <span>Support Us</span>
          </a>
        </nb-sidebar-header>
        <ng-content select="nb-menu"></ng-content>
      </nb-sidebar>

      <nb-layout-column class="small">
      </nb-layout-column>

      <nb-layout-column>
        <ng-content select="router-outlet"></ng-content>
      </nb-layout-column>

      <nb-layout-column class="small">
      </nb-layout-column>

      <nb-layout-footer fixed>
        <ngx-footer></ngx-footer>
      </nb-layout-footer>
    </nb-layout>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-default :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-default :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#fff;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.375rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.375rem}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-default :host .main-btn{display:none}}.nb-theme-cosmic :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-cosmic :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#2f296b;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.5rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.5rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-cosmic :host .main-btn{display:none}}.nb-theme-corporate :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-corporate :host nb-sidebar.settings-sidebar{-webkit-transition:width .3s;transition:width .3s;width:7.5rem;overflow:hidden}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed{width:0}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container{width:0}.nb-theme-corporate :host nb-sidebar.settings-sidebar.collapsed /deep/ .main-container .scrollable{width:7.5rem;padding:1.25rem}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container{width:7.5rem;background:#fff;-webkit-transition:width .3s;transition:width .3s;overflow:hidden}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:7.5rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0;background:0 0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border:1px solid #cdd5dc;height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.17rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable{padding-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable .menu-item:first-child{border-top:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48);border-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:399.98px){.nb-theme-default :host .main-content{padding:.75rem!important}.nb-theme-cosmic :host .main-content{padding:.75rem!important}.nb-theme-corporate :host .main-content{padding:.75rem!important}}@media (max-width:767.98px){.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-corporate :host .main-btn{display:none}}"]
            }] }
];
/** @nocollapse */
ThreeColumnsLayoutComponent.ctorParameters = () => [
    { type: NbThemeService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// TODO: move layouts into the framework
class SampleLayoutComponent {
    /**
     * @param {?} stateService
     * @param {?} menuService
     * @param {?} themeService
     * @param {?} bpService
     * @param {?} sidebarService
     */
    constructor(stateService, menuService, themeService, bpService, sidebarService) {
        this.stateService = stateService;
        this.menuService = menuService;
        this.themeService = themeService;
        this.bpService = bpService;
        this.sidebarService = sidebarService;
        this.subMenu = [
            {
                title: 'PAGE LEVEL MENU',
                group: true,
            },
            {
                title: 'Buttons',
                icon: 'ion ion-android-radio-button-off',
                link: '/pages/ui-features/buttons',
            },
            {
                title: 'Grid',
                icon: 'ion ion-android-radio-button-off',
                link: '/pages/ui-features/grid',
            },
            {
                title: 'Icons',
                icon: 'ion ion-android-radio-button-off',
                link: '/pages/ui-features/icons',
            },
            {
                title: 'Modals',
                icon: 'ion ion-android-radio-button-off',
                link: '/pages/ui-features/modals',
            },
            {
                title: 'Typography',
                icon: 'ion ion-android-radio-button-off',
                link: '/pages/ui-features/typography',
            },
            {
                title: 'Animated Searches',
                icon: 'ion ion-android-radio-button-off',
                link: '/pages/ui-features/search-fields',
            },
            {
                title: 'Tabs',
                icon: 'ion ion-android-radio-button-off',
                link: '/pages/ui-features/tabs',
            },
        ];
        this.layout = {};
        this.sidebar = {};
        this.alive = true;
        this.stateService.onLayoutState()
            .pipe(takeWhile(() => this.alive))
            .subscribe((layout) => this.layout = layout);
        this.stateService.onSidebarState()
            .pipe(takeWhile(() => this.alive))
            .subscribe((sidebar) => {
            this.sidebar = sidebar;
        });
        /** @type {?} */
        const isBp = this.bpService.getByName('is');
        this.menuService.onItemSelect()
            .pipe(takeWhile(() => this.alive), withLatestFrom(this.themeService.onMediaQueryChange()), delay(20))
            .subscribe(([item, [bpFrom, bpTo]]) => {
            if (bpTo.width <= isBp.width) {
                this.sidebarService.collapse('menu-sidebar');
            }
        });
        this.themeService.getJsTheme()
            .pipe(takeWhile(() => this.alive))
            .subscribe(theme => {
            this.currentTheme = theme.name;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.alive = false;
    }
}
SampleLayoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-sample-layout',
                template: `
    <nb-layout [center]="layout.id === 'center-column'" windowMode>
      <nb-layout-header fixed>
        <ngx-header [position]="sidebar.id === 'start' ? 'normal': 'inverse'"></ngx-header>
      </nb-layout-header>

      <nb-sidebar class="menu-sidebar"
                   tag="menu-sidebar"
                   responsive
                   [end]="sidebar.id === 'end'">
        <nb-sidebar-header *ngIf="currentTheme !== 'corporate'">
          <a href="#" class="btn btn-hero-success main-btn">
            <i class="ion ion-social-github"></i> <span>Support Us</span>
          </a>
        </nb-sidebar-header>
        <ng-content select="nb-menu"></ng-content>
      </nb-sidebar>

      <nb-layout-column class="main-content">
        <ng-content select="router-outlet"></ng-content>
      </nb-layout-column>

      <nb-layout-column start class="small" *ngIf="layout.id === 'two-column' || layout.id === 'three-column'">
        <nb-menu [items]="subMenu"></nb-menu>
      </nb-layout-column>

      <nb-layout-column class="small" *ngIf="layout.id === 'three-column'">
        <nb-menu [items]="subMenu"></nb-menu>
      </nb-layout-column>

      <nb-layout-footer fixed>
        <ngx-footer></ngx-footer>
      </nb-layout-footer>

      <nb-sidebar class="settings-sidebar"
                   tag="settings-sidebar"
                   state="collapsed"
                   fixed
                   [end]="sidebar.id !== 'end'">
        <ngx-theme-settings></ngx-theme-settings>
      </nb-sidebar>
    </nb-layout>
    <ngx-toggle-settings-button></ngx-toggle-settings-button>
  `,
                styles: ["/*!\n * @license\n * Copyright Akveo. All Rights Reserved.\n * Licensed under the MIT License. See License.txt in the project root for license information.\n */.nb-theme-default :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-default :host nb-sidebar.settings-sidebar{-webkit-transition:-webkit-transform .3s;transition:transform .3s;transition:transform .3s,-webkit-transform .3s;width:19rem;overflow:hidden}[dir=ltr] .nb-theme-default :host nb-sidebar.settings-sidebar{-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}[dir=rtl] .nb-theme-default :host nb-sidebar.settings-sidebar{-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}[dir=ltr] .nb-theme-default :host nb-sidebar.settings-sidebar.start{-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}[dir=rtl] .nb-theme-default :host nb-sidebar.settings-sidebar.start{-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}.nb-theme-default :host nb-sidebar.settings-sidebar.expanded,.nb-theme-default :host nb-sidebar.settings-sidebar.expanded.start{-webkit-transform:translate3d(0,0,0);transform:translate3d(0,0,0)}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .scrollable{width:19rem;padding:3.4rem .25rem}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container{width:19rem;background:#fff;-webkit-transition:-webkit-transform .3s;transition:transform .3s;transition:transform .3s,-webkit-transform .3s;overflow:hidden;position:relative}.nb-theme-default :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:19rem}.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.375rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.375rem}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-default :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ nb-menu>.menu-items>.menu-item:first-child .menu-title::after{content:'new';color:#fff;margin-left:1rem;background:#ff4c6a;padding:0 .5rem;border-radius:.375rem;font-size:.875rem}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ nb-menu .nb-e-commerce{font-size:2rem}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-default :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-default :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-default :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-default :host .main-btn{display:none}}.nb-theme-cosmic :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-cosmic :host nb-sidebar.settings-sidebar{-webkit-transition:-webkit-transform .3s;transition:transform .3s;transition:transform .3s,-webkit-transform .3s;width:19rem;overflow:hidden}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.settings-sidebar{-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.settings-sidebar{-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.settings-sidebar.start{-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.settings-sidebar.start{-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}.nb-theme-cosmic :host nb-sidebar.settings-sidebar.expanded,.nb-theme-cosmic :host nb-sidebar.settings-sidebar.expanded.start{-webkit-transform:translate3d(0,0,0);transform:translate3d(0,0,0)}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .scrollable{width:19rem;padding:3.4rem .25rem}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container{width:19rem;background:#2f296b;-webkit-transition:-webkit-transform .3s;transition:transform .3s;transition:transform .3s,-webkit-transform .3s;overflow:hidden;position:relative}.nb-theme-cosmic :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:19rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:2rem;background:0 0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem - 2rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.5rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.5rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48)}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-cosmic :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ nb-menu>.menu-items>.menu-item:first-child .menu-title::after{content:'new';color:#fff;margin-left:1rem;background:#ff386a;padding:0 .5rem;border-radius:.5rem;font-size:.875rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ nb-menu .nb-e-commerce{font-size:2rem}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-cosmic :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:767.98px){.nb-theme-cosmic :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-cosmic :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-cosmic :host .main-btn{display:none}}.nb-theme-corporate :host nb-layout-column.small{-webkit-box-flex:.15!important;-ms-flex:.15!important;flex:.15!important}.nb-theme-corporate :host nb-sidebar.settings-sidebar{-webkit-transition:-webkit-transform .3s;transition:transform .3s;transition:transform .3s,-webkit-transform .3s;width:19rem;overflow:hidden}[dir=ltr] .nb-theme-corporate :host nb-sidebar.settings-sidebar{-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}[dir=rtl] .nb-theme-corporate :host nb-sidebar.settings-sidebar{-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}[dir=ltr] .nb-theme-corporate :host nb-sidebar.settings-sidebar.start{-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}[dir=rtl] .nb-theme-corporate :host nb-sidebar.settings-sidebar.start{-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}.nb-theme-corporate :host nb-sidebar.settings-sidebar.expanded,.nb-theme-corporate :host nb-sidebar.settings-sidebar.expanded.start{-webkit-transform:translate3d(0,0,0);transform:translate3d(0,0,0)}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .scrollable{width:19rem;padding:3.4rem .25rem}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container{width:19rem;background:#fff;-webkit-transition:-webkit-transform .3s;transition:transform .3s;transition:transform .3s,-webkit-transform .3s;overflow:hidden;position:relative}.nb-theme-corporate :host nb-sidebar.settings-sidebar /deep/ .main-container .scrollable{width:19rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0;background:0 0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border:1px solid #cdd5dc;height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:.17rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable{padding-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .scrollable .menu-item:first-child{border-top:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ nb-sidebar-header{padding-bottom:.5rem;text-align:center}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn{padding:.75rem 2.5rem;margin-top:-2rem;font-weight:700;-webkit-transition:padding .3s cubic-bezier(.18,.89,.32,1.48);transition:padding .3s cubic-bezier(.18,.89,.32,1.48);border-radius:.17rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i{font-size:2rem;text-shadow:0 1px 1px rgba(0,0,0,.2)}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-left:.25rem}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{padding-right:.25rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn i,.nb-theme-corporate :host nb-sidebar.menu-sidebar .main-btn span{vertical-align:middle}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ nb-menu>.menu-items>.menu-item:first-child .menu-title::after{content:'new';color:#fff;margin-left:1rem;background:#ff6b83;padding:0 .5rem;border-radius:.17rem;font-size:.875rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ nb-menu .nb-e-commerce{font-size:2rem}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted /deep/ nb-sidebar-header{padding-left:0;padding-right:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn{width:46px;height:44px;padding:.375rem;border-radius:5px;-webkit-transition:none;transition:none}.nb-theme-corporate :host nb-sidebar.menu-sidebar.compacted .main-btn span{display:none}@media (max-width:399.98px){.nb-theme-default :host .main-content{padding:.75rem!important}.nb-theme-cosmic :host .main-content{padding:.75rem!important}.nb-theme-corporate :host .main-content{padding:.75rem!important}}@media (max-width:767.98px){.nb-theme-corporate :host nb-sidebar.menu-sidebar{margin-top:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{height:calc(100vh - 4.75rem)!important}[dir=ltr] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-right-radius:0}[dir=rtl] .nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container{border-top-left-radius:0}.nb-theme-corporate :host nb-sidebar.menu-sidebar /deep/ .main-container .scrollable{padding-top:0}.nb-theme-corporate :host .main-btn{display:none}}"]
            }] }
];
/** @nocollapse */
SampleLayoutComponent.ctorParameters = () => [
    { type: StateService },
    { type: NbMenuService },
    { type: NbThemeService },
    { type: NbMediaBreakpointsService },
    { type: NbSidebarService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const DEFAULT_THEME = {
    name: 'default',
    base: null,
    variables: {
        // Safari fix
        temperature: [
            '#42db7d',
            '#42db7d',
            '#42db7d',
            '#42db7d',
            '#42db7d',
        ],
        solar: {
            gradientLeft: '#42db7d',
            gradientRight: '#42db7d',
            shadowColor: 'rgba(0, 0, 0, 0)',
            radius: ['80%', '90%'],
        },
        traffic: {
            colorBlack: '#000000',
            tooltipBg: '#ffffff',
            tooltipBorderColor: '#c0c8d1',
            tooltipExtraCss: 'border-radius: 10px; padding: 4px 16px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            lineBg: '#c0c8d1',
            lineShadowBlur: '1',
            itemColor: '#bcc3cc',
            itemBorderColor: '#bcc3cc',
            itemEmphasisBorderColor: '#42db7d',
            shadowLineDarkBg: 'rgba(0, 0, 0, 0)',
            shadowLineShadow: 'rgba(0, 0, 0, 0)',
            gradFrom: '#ebeef2',
            gradTo: '#ebeef2',
        },
        electricity: {
            tooltipBg: '#ffffff',
            tooltipLineColor: 'rgba(0, 0, 0, 0)',
            tooltipLineWidth: '0',
            tooltipBorderColor: '#ebeef2',
            tooltipExtraCss: 'border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            axisLineColor: 'rgba(0, 0, 0, 0)',
            xAxisTextColor: '#2a2a2a',
            yAxisSplitLine: '#ebeef2',
            itemBorderColor: '#42db7d',
            lineStyle: 'solid',
            lineWidth: '4',
            lineGradFrom: '#42db7d',
            lineGradTo: '#42db7d',
            lineShadow: 'rgba(0, 0, 0, 0)',
            areaGradFrom: 'rgba(235, 238, 242, 0.5)',
            areaGradTo: 'rgba(235, 238, 242, 0.5)',
            shadowLineDarkBg: 'rgba(0, 0, 0, 0)',
        },
        bubbleMap: {
            titleColor: '#484848',
            areaColor: '#dddddd',
            areaHoverColor: '#cccccc',
            areaBorderColor: '#ebeef2',
        },
        profitBarAnimationEchart: {
            textColor: '#484848',
            firstAnimationBarColor: '#3edd81',
            secondAnimationBarColor: '#8d7fff',
            splitLineStyleOpacity: '0.06',
            splitLineStyleWidth: '1',
            splitLineStyleColor: '#000000',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            tooltipFontSize: '16',
            tooltipBg: '#ffffff',
            tooltipBorderColor: '#c0c8d1',
            tooltipBorderWidth: '3',
            tooltipExtraCss: 'border-radius: 10px; padding: 4px 16px;',
        },
        trafficBarEchart: {
            gradientFrom: '#fc0',
            gradientTo: '#ffa100',
            shadow: '#ffb600',
            shadowBlur: '0',
            axisTextColor: '#b2bac2',
            axisFontSize: '12',
            tooltipBg: '#ffffff',
            tooltipBorderColor: '#c0c8d1',
            tooltipExtraCss: 'border-radius: 10px; padding: 4px 16px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
        },
        countryOrders: {
            countryBorderColor: 'rgba(255, 255, 255, 1)',
            countryFillColor: 'rgba(236, 242, 245, 1)',
            countryBorderWidth: '1',
            hoveredCountryBorderColor: '#40dc7e',
            hoveredCountryFillColor: '#c7f4d9',
            hoveredCountryBorderWidth: '3',
            chartAxisLineColor: 'rgba(0, 0, 0, 0)',
            chartAxisTextColor: '#b2bac2',
            chartAxisFontSize: '16',
            chartGradientTo: '#3edd81',
            chartGradientFrom: '#3bddaf',
            chartAxisSplitLine: '#ebeef2',
            chartShadowLineColor: '#2f296b',
            chartLineBottomShadowColor: '#eceff4',
            chartInnerLineColor: '#eceff4',
        },
        echarts: {
            bg: '#ffffff',
            textColor: '#484848',
            axisLineColor: '#bbbbbb',
            splitLineColor: '#ebeef2',
            itemHoverShadowColor: 'rgba(0, 0, 0, 0.5)',
            tooltipBackgroundColor: '#6a7985',
            areaOpacity: '0.7',
        },
        chartjs: {
            axisLineColor: '#cccccc',
            textColor: '#484848',
        },
        orders: {
            tooltipBg: '#ffffff',
            tooltipLineColor: 'rgba(0, 0, 0, 0)',
            tooltipLineWidth: '0',
            tooltipBorderColor: '#ebeef2',
            tooltipExtraCss: 'border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            tooltipFontSize: '20',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            axisFontSize: '16',
            axisTextColor: '#b2bac2',
            yAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            itemBorderColor: '#42db7d',
            lineStyle: 'solid',
            lineWidth: '4',
            // first line
            firstAreaGradFrom: 'rgba(236, 242, 245, 0.8)',
            firstAreaGradTo: 'rgba(236, 242, 245, 0.8)',
            firstShadowLineDarkBg: 'rgba(0, 0, 0, 0)',
            // second line
            secondLineGradFrom: 'rgba(164, 123, 255, 1)',
            secondLineGradTo: 'rgba(164, 123, 255, 1)',
            secondAreaGradFrom: 'rgba(188, 92, 255, 0.2)',
            secondAreaGradTo: 'rgba(188, 92, 255, 0)',
            secondShadowLineDarkBg: 'rgba(0, 0, 0, 0)',
            // third line
            thirdLineGradFrom: 'rgba(55, 220, 136, 1)',
            thirdLineGradTo: 'rgba(55, 220, 136, 1)',
            thirdAreaGradFrom: 'rgba(31 ,106, 124, 0.2)',
            thirdAreaGradTo: 'rgba(4, 126, 230, 0)',
            thirdShadowLineDarkBg: 'rgba(0, 0, 0, 0)',
        },
        // TODO: need design for default theme
        profit: {
            bg: '#ffffff',
            textColor: '#ffffff',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            splitLineColor: 'rgba(161, 161 ,229, 0.2)',
            areaOpacity: '1',
            axisFontSize: '16',
            axisTextColor: '#b2bac2',
            // first bar
            firstLineGradFrom: '#00bece',
            firstLineGradTo: '#00da78',
            firstLineShadow: 'rgba(14, 16, 48, 0.4)',
            // second bar
            secondLineGradFrom: '#8069ff',
            secondLineGradTo: '#8357ff',
            secondLineShadow: 'rgba(14, 16, 48, 0.4)',
            // third bar
            thirdLineGradFrom: 'rgba(236, 242, 245, 0.8)',
            thirdLineGradTo: 'rgba(236, 242, 245, 0.8)',
            thirdLineShadow: 'rgba(14, 16, 48, 0.4)',
        },
        orderProfitLegend: {
            firstItem: 'linear-gradient(90deg, #3edd81 0%, #3bddad 100%)',
            secondItem: 'linear-gradient(90deg, #8d7fff 0%, #b17fff 100%)',
            thirdItem: 'rgba(236, 242, 245, 0.8)',
        },
        visitors: {
            tooltipBg: '#ffffff',
            tooltipLineColor: 'rgba(0, 0, 0, 0)',
            tooltipLineWidth: '0',
            tooltipBorderColor: '#ebeef2',
            tooltipExtraCss: 'border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            tooltipFontSize: '20',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            axisFontSize: '16',
            axisTextColor: '#b2bac2',
            yAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            itemBorderColor: '#42db7d',
            lineStyle: 'dotted',
            lineWidth: '6',
            lineGradFrom: '#ffffff',
            lineGradTo: '#ffffff',
            lineShadow: 'rgba(14, 16, 48, 0)',
            areaGradFrom: 'rgba(188, 92, 255, 1)',
            areaGradTo: 'rgba(188, 92, 255, 0.5)',
            shadowLineDarkBg: '#a695ff',
            innerLineStyle: 'solid',
            innerLineWidth: '1',
            innerAreaGradFrom: 'rgba(60, 221, 156, 1)',
            innerAreaGradTo: 'rgba(60, 221, 156, 1)',
        },
        visitorsLegend: {
            firstIcon: 'linear-gradient(90deg, #3edd81 0%, #3bddad 100%)',
            secondIcon: 'linear-gradient(90deg, #8d7fff 0%, #b17fff 100%)',
        },
        visitorsPie: {
            firstPieGradientLeft: '#8defbb',
            firstPieGradientRight: '#8defbb',
            firstPieShadowColor: 'rgba(0, 0, 0, 0)',
            firstPieRadius: ['70%', '90%'],
            secondPieGradientLeft: '#ff894a',
            secondPieGradientRight: '#ffcc10',
            secondPieShadowColor: 'rgba(0, 0, 0, 0)',
            secondPieRadius: ['60%', '97%'],
            shadowOffsetX: '0',
            shadowOffsetY: '0',
        },
        visitorsPieLegend: {
            firstSection: 'linear-gradient(90deg, #ffcb17 0%, #ff874c 100%)',
            secondSection: '#8defbb',
        },
        earningPie: {
            radius: ['65%', '100%'],
            center: ['50%', '50%'],
            fontSize: '22',
            firstPieGradientLeft: '#00d77f',
            firstPieGradientRight: '#00d77f',
            firstPieShadowColor: 'rgba(0, 0, 0, 0)',
            secondPieGradientLeft: '#7756f7',
            secondPieGradientRight: '#7756f7',
            secondPieShadowColor: 'rgba(0, 0, 0, 0)',
            thirdPieGradientLeft: '#ffca00',
            thirdPieGradientRight: '#ffca00',
            thirdPieShadowColor: 'rgba(0, 0, 0, 0)',
        },
        earningLine: {
            gradFrom: 'rgba(188, 92, 255, 0.5)',
            gradTo: 'rgba(188, 92, 255, 0.5)',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            tooltipFontSize: '16',
            tooltipBg: '#ffffff',
            tooltipBorderColor: '#c0c8d1',
            tooltipBorderWidth: '3',
            tooltipExtraCss: 'border-radius: 10px; padding: 4px 16px;',
        },
    },
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const COSMIC_THEME = {
    name: 'cosmic',
    base: 'default',
    variables: {
        temperature: [
            '#2ec7fe',
            '#31ffad',
            '#7bff24',
            '#fff024',
            '#f7bd59',
        ],
        solar: {
            gradientLeft: '#7bff24',
            gradientRight: '#2ec7fe',
            shadowColor: '#19977E',
            radius: ['70%', '90%'],
        },
        traffic: {
            colorBlack: '#000000',
            tooltipBg: 'rgba(0, 255, 170, 0.35)',
            tooltipBorderColor: '#00d977',
            tooltipExtraCss: 'box-shadow: 0px 2px 46px 0 rgba(0, 255, 170, 0.35); border-radius: 10px; padding: 4px 16px;',
            tooltipTextColor: '#ffffff',
            tooltipFontWeight: 'normal',
            lineBg: '#d1d1ff',
            lineShadowBlur: '14',
            itemColor: '#BEBBFF',
            itemBorderColor: '#ffffff',
            itemEmphasisBorderColor: '#ffffff',
            shadowLineDarkBg: '#655ABD',
            shadowLineShadow: 'rgba(33, 7, 77, 0.5)',
            gradFrom: 'rgba(118, 89, 255, 0.4)',
            gradTo: 'rgba(164, 84, 255, 0.5)',
        },
        electricity: {
            tooltipBg: 'rgba(0, 255, 170, 0.35)',
            tooltipLineColor: 'rgba(255, 255, 255, 0.1)',
            tooltipLineWidth: '1',
            tooltipBorderColor: '#00d977',
            tooltipExtraCss: 'box-shadow: 0px 2px 46px 0 rgba(0, 255, 170, 0.35); border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#ffffff',
            tooltipFontWeight: 'normal',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            xAxisTextColor: '#a1a1e5',
            yAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            itemBorderColor: '#ffffff',
            lineStyle: 'dotted',
            lineWidth: '6',
            lineGradFrom: '#00ffaa',
            lineGradTo: '#fff835',
            lineShadow: 'rgba(14, 16, 48, 0.4)',
            areaGradFrom: 'rgba(188, 92, 255, 0.5)',
            areaGradTo: 'rgba(188, 92, 255, 0)',
            shadowLineDarkBg: '#a695ff',
        },
        bubbleMap: {
            titleColor: '#ffffff',
            areaColor: '#2c2961',
            areaHoverColor: '#a1a1e5',
            areaBorderColor: '#654ddb',
        },
        profitBarAnimationEchart: {
            textColor: '#ffffff',
            firstAnimationBarColor: '#0088ff',
            secondAnimationBarColor: '#7659ff',
            splitLineStyleOpacity: '0.06',
            splitLineStyleWidth: '1',
            splitLineStyleColor: '#000000',
            tooltipTextColor: '#ffffff',
            tooltipFontWeight: 'normal',
            tooltipFontSize: '16',
            tooltipBg: 'rgba(0, 255, 170, 0.35)',
            tooltipBorderColor: '#00d977',
            tooltipBorderWidth: '3',
            tooltipExtraCss: 'box-shadow: 0px 2px 46px 0 rgba(0, 255, 170, 0.35); border-radius: 10px; padding: 4px 16px;',
        },
        trafficBarEchart: {
            gradientFrom: '#fc0',
            gradientTo: '#ffa100',
            shadow: '#ffb600',
            shadowBlur: '5',
            axisTextColor: '#a1a1e5',
            axisFontSize: '12',
            tooltipBg: 'rgba(0, 255, 170, 0.35)',
            tooltipBorderColor: '#00d977',
            tooltipExtraCss: 'box-shadow: 0px 2px 46px 0 rgba(0, 255, 170, 0.35); border-radius: 10px; padding: 4px 16px;',
            tooltipTextColor: '#ffffff',
            tooltipFontWeight: 'normal',
        },
        countryOrders: {
            countryBorderColor: '#525dbd',
            countryFillColor: '#4f41a6',
            countryBorderWidth: '2',
            hoveredCountryBorderColor: '#00f9a6',
            hoveredCountryFillColor: '#377aa7',
            hoveredCountryBorderWidth: '3',
            chartAxisLineColor: 'rgba(161, 161 ,229, 0.3)',
            chartAxisTextColor: '#a1a1e5',
            chartAxisFontSize: '16',
            chartGradientTo: '#00c7c7',
            chartGradientFrom: '#00d977',
            chartAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            chartShadowBarColor: '#2f296b',
            chartLineBottomShadowColor: '#00977e',
            chartInnerLineColor: '#2f296b',
        },
        echarts: {
            bg: '#3d3780',
            textColor: '#ffffff',
            axisLineColor: '#a1a1e5',
            splitLineColor: '#342e73',
            itemHoverShadowColor: 'rgba(0, 0, 0, 0.5)',
            tooltipBackgroundColor: '#6a7985',
            areaOpacity: '1',
        },
        chartjs: {
            axisLineColor: '#a1a1e5',
            textColor: '#ffffff',
        },
        orders: {
            tooltipBg: 'rgba(0, 255, 170, 0.35)',
            tooltipLineColor: 'rgba(255, 255, 255, 0.1)',
            tooltipLineWidth: '1',
            tooltipBorderColor: '#00d977',
            tooltipExtraCss: 'box-shadow: 0px 2px 46px 0 rgba(0, 255, 170, 0.35); border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#ffffff',
            tooltipFontWeight: 'normal',
            tooltipFontSize: '20',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            axisFontSize: '16',
            axisTextColor: '#a1a1e5',
            yAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            itemBorderColor: '#ffffff',
            lineStyle: 'solid',
            lineWidth: '4',
            // first line
            firstAreaGradFrom: 'rgba(78, 64, 164, 1)',
            firstAreaGradTo: 'rgba(78, 64, 164, 1)',
            firstShadowLineDarkBg: '#018dff',
            // second line
            secondLineGradFrom: '#00bece',
            secondLineGradTo: '#00da78',
            secondAreaGradFrom: 'rgba(38, 139, 145, 0.8)',
            secondAreaGradTo: 'rgba(38, 139, 145, 0.5)',
            secondShadowLineDarkBg: '#2c5a85',
            // third line
            thirdLineGradFrom: '#8069ff',
            thirdLineGradTo: '#8357ff',
            thirdAreaGradFrom: 'rgba(118, 73, 208, 0.7)',
            thirdAreaGradTo: 'rgba(188, 92, 255, 0.4)',
            thirdShadowLineDarkBg: '#a695ff',
        },
        profit: {
            bg: '#3d3780',
            textColor: '#ffffff',
            axisLineColor: '#a1a1e5',
            splitLineColor: '#342e73',
            areaOpacity: '1',
            axisFontSize: '16',
            axisTextColor: '#a1a1e5',
            // first bar
            firstLineGradFrom: '#00bece',
            firstLineGradTo: '#00da78',
            firstLineShadow: 'rgba(14, 16, 48, 0.4)',
            // second bar
            secondLineGradFrom: '#8069ff',
            secondLineGradTo: '#8357ff',
            secondLineShadow: 'rgba(14, 16, 48, 0.4)',
            // third bar
            thirdLineGradFrom: '#4e40a4',
            thirdLineGradTo: '#4e40a4',
            thirdLineShadow: 'rgba(14, 16, 48, 0.4)',
        },
        orderProfitLegend: {
            firstItem: 'linear-gradient(90deg, #00c7c7 0%, #00d977 100%)',
            secondItem: 'linear-gradient(90deg, #a454ff 0%, #7659ff 100%)',
            thirdItem: '#4e40a4',
        },
        visitors: {
            tooltipBg: 'rgba(0, 255, 170, 0.35)',
            tooltipLineColor: 'rgba(255, 255, 255, 0.1)',
            tooltipLineWidth: '1',
            tooltipBorderColor: '#00d977',
            tooltipExtraCss: 'box-shadow: 0px 2px 46px 0 rgba(0, 255, 170, 0.35); border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#ffffff',
            tooltipFontWeight: 'normal',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            axisFontSize: '16',
            axisTextColor: '#a1a1e5',
            yAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            itemBorderColor: '#ffffff',
            lineStyle: 'dotted',
            lineWidth: '6',
            lineGradFrom: '#ffffff',
            lineGradTo: '#ffffff',
            lineShadow: 'rgba(14, 16, 48, 0.4)',
            areaGradFrom: 'rgba(188, 92, 255, 1)',
            areaGradTo: 'rgba(188, 92, 255, 0.5)',
            shadowLineDarkBg: '#a695ff',
            innerLineStyle: 'solid',
            innerLineWidth: '1',
            innerAreaGradFrom: 'rgba(59, 165, 243, 1)',
            innerAreaGradTo: 'rgba(4, 133, 243 , 1)',
        },
        visitorsLegend: {
            firstIcon: 'linear-gradient(90deg, #0088ff 0%, #3dafff 100%)',
            secondIcon: 'linear-gradient(90deg, #a454ff 0%, #7659ff 100%)',
        },
        visitorsPie: {
            firstPieGradientLeft: '#7bff24',
            firstPieGradientRight: '#2ec7fe',
            firstPieShadowColor: '#19977E',
            firstPieRadius: ['70%', '90%'],
            secondPieGradientLeft: '#ff894a',
            secondPieGradientRight: '#ffcc10',
            secondPieShadowColor: '#cf7c1c',
            secondPieRadius: ['60%', '95%'],
            shadowOffsetX: '0',
            shadowOffsetY: '3',
        },
        visitorsPieLegend: {
            firstSection: 'linear-gradient(90deg, #ffcb17 0%, #ff874c 100%)',
            secondSection: 'linear-gradient(90deg, #00c7c7 0%, #00d977 100%)',
        },
        earningPie: {
            radius: ['65%', '100%'],
            center: ['50%', '50%'],
            fontSize: '22',
            firstPieGradientLeft: '#00d77f',
            firstPieGradientRight: '#00d77f',
            firstPieShadowColor: 'rgba(0, 0, 0, 0)',
            secondPieGradientLeft: '#7756f7',
            secondPieGradientRight: '#7756f7',
            secondPieShadowColor: 'rgba(0, 0, 0, 0)',
            thirdPieGradientLeft: '#ffca00',
            thirdPieGradientRight: '#ffca00',
            thirdPieShadowColor: 'rgba(0, 0, 0, 0)',
        },
        earningLine: {
            gradFrom: 'rgba(118, 89, 255, 0.4)',
            gradTo: 'rgba(164, 84, 255, 0.5)',
            tooltipTextColor: '#ffffff',
            tooltipFontWeight: 'normal',
            tooltipFontSize: '16',
            tooltipBg: 'rgba(0, 255, 170, 0.35)',
            tooltipBorderColor: '#00d977',
            tooltipBorderWidth: '3',
            tooltipExtraCss: 'box-shadow: 0px 2px 46px 0 rgba(0, 255, 170, 0.35); border-radius: 10px; padding: 4px 16px;',
        },
    },
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const CORPORATE_THEME = {
    name: 'corporate',
    base: 'default',
    variables: {
        temperature: [
            '#ffa36b',
            '#ffa36b',
            '#ff9e7a',
            '#ff9888',
            '#ff8ea0',
        ],
        solar: {
            gradientLeft: '#ff8ea0',
            gradientRight: '#ffa36b',
            shadowColor: 'rgba(0, 0, 0, 0)',
            radius: ['80%', '90%'],
        },
        traffic: {
            colorBlack: '#ffffff',
            tooltipBg: '#eef2f5',
            tooltipBorderColor: '#eef2f5',
            tooltipExtraCss: 'border-radius: 10px; padding: 4px 16px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: '400',
            lineBg: '#cae6f3',
            lineShadowBlur: '0',
            itemColor: '#bcc3cc',
            itemBorderColor: '#bcc3cc',
            itemEmphasisBorderColor: '#74a2ff',
            shadowLineDarkBg: 'rgba(0, 0, 0, 0)',
            shadowLineShadow: 'rgba(0, 0, 0, 0)',
            gradFrom: '#ffffff',
            gradTo: '#ffffff',
        },
        electricity: {
            tooltipBg: '#edf0f4',
            tooltipLineColor: '#bdc4cd',
            tooltipLineWidth: '0',
            tooltipBorderColor: '#ebeef2',
            tooltipExtraCss: 'border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            axisLineColor: 'rgba(0, 0, 0, 0)',
            xAxisTextColor: '#2a2a2a',
            yAxisSplitLine: '#ebeef2',
            itemBorderColor: '#73a1ff',
            lineStyle: 'solid',
            lineWidth: '4',
            lineGradFrom: '#bdc4cd',
            lineGradTo: '#c0c8d1',
            lineShadow: 'rgba(0, 0, 0, 0)',
            areaGradFrom: 'rgba(255, 255, 255, 0)',
            areaGradTo: 'rgba(255, 255, 255, 0)',
            shadowLineDarkBg: 'rgba(255, 255, 255, 0)',
        },
        bubbleMap: {
            titleColor: '#484848',
            areaColor: '#dddddd',
            areaHoverColor: '#cccccc',
            areaBorderColor: '#ebeef2',
        },
        profitBarAnimationEchart: {
            textColor: '#b2bac2',
            firstAnimationBarColor: '#719efc',
            secondAnimationBarColor: '#5dcfe3',
            splitLineStyleOpacity: '0.06',
            splitLineStyleWidth: '1',
            splitLineStyleColor: '#000000',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: '400',
            tooltipFontSize: '16',
            tooltipBg: '#eef2f5',
            tooltipBorderColor: '#eef2f5',
            tooltipBorderWidth: '3',
            tooltipExtraCss: 'border-radius: 10px; padding: 4px 16px;',
        },
        trafficBarEchart: {
            gradientFrom: '#ff8ea0',
            gradientTo: '#ffa36b',
            shadow: 'rgba(0, 0, 0, 0)',
            shadowBlur: '0',
            axisTextColor: '#b2bac2',
            axisFontSize: '12',
            tooltipBg: '#edf0f4',
            tooltipBorderColor: '#ebeef2',
            tooltipExtraCss: 'border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
        },
        countryOrders: {
            countryBorderColor: 'rgba(255, 255, 255, 1)',
            countryFillColor: 'rgba(236, 242, 245, 1)',
            countryBorderWidth: '1',
            hoveredCountryBorderColor: 'rgba(113, 158, 252, 1)',
            hoveredCountryFillColor: 'rgba(199, 216, 247, 1)',
            hoveredCountryBorderWidth: '3',
            chartAxisLineColor: 'rgba(0, 0, 0, 0)',
            chartAxisTextColor: '#b2bac2',
            chartAxisFontSize: '16',
            chartGradientTo: 'rgba(113, 158, 252, 1)',
            chartGradientFrom: 'rgba(113, 158, 252, 1)',
            chartAxisSplitLine: '#ebeef2',
            chartShadowLineColor: '#2f296b',
            chartLineBottomShadowColor: 'rgba(113, 158, 252, 1)',
            chartInnerLineColor: '#eceff4',
        },
        echarts: {
            bg: '#ffffff',
            textColor: '#484848',
            axisLineColor: '#bbbbbb',
            splitLineColor: '#ebeef2',
            itemHoverShadowColor: 'rgba(0, 0, 0, 0.5)',
            tooltipBackgroundColor: '#6a7985',
            areaOpacity: '0.7',
        },
        chartjs: {
            axisLineColor: '#cccccc',
            textColor: '#484848',
        },
        orders: {
            tooltipBg: '#ffffff',
            tooltipLineColor: 'rgba(0, 0, 0, 0)',
            tooltipLineWidth: '0',
            tooltipBorderColor: '#ebeef2',
            tooltipExtraCss: 'border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            tooltipFontSize: '20',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            axisFontSize: '16',
            axisTextColor: '#b2bac2',
            yAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            itemBorderColor: '#73a1ff',
            lineStyle: 'solid',
            lineWidth: '4',
            // first line
            firstAreaGradFrom: 'rgba(227, 236, 254, 0.7)',
            firstAreaGradTo: 'rgba(227, 236, 254, 0.7)',
            firstShadowLineDarkBg: 'rgba(0, 0, 0, 0)',
            // second line
            secondLineGradFrom: 'rgba(93, 207, 227, 1)',
            secondLineGradTo: 'rgba(93, 207, 227, 1)',
            secondAreaGradFrom: 'rgba(0, 0, 0, 0)',
            secondAreaGradTo: 'rgba(0, 0, 0, 0)',
            secondShadowLineDarkBg: 'rgba(0, 0, 0, 0)',
            // third line
            thirdLineGradFrom: 'rgba(113, 158, 252, 1)',
            thirdLineGradTo: 'rgba(113, 158, 252, 1)',
            thirdAreaGradFrom: 'rgba(0, 0, 0, 0)',
            thirdAreaGradTo: 'rgba(0, 0, 0, 0)',
            thirdShadowLineDarkBg: 'rgba(0, 0, 0, 0)',
        },
        profit: {
            bg: '#ffffff',
            textColor: '#ffffff',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            splitLineColor: 'rgba(161, 161 ,229, 0.2)',
            areaOpacity: '1',
            axisFontSize: '16',
            axisTextColor: '#b2bac2',
            // first bar
            firstLineGradFrom: '#719efc',
            firstLineGradTo: '#719efc',
            firstLineShadow: 'rgba(14, 16, 48, 0.4)',
            // second bar
            secondLineGradFrom: '#5dcfe3',
            secondLineGradTo: '#5dcfe3',
            secondLineShadow: 'rgba(14, 16, 48, 0.4)',
            // third bar
            thirdLineGradFrom: '#e3ecfe',
            thirdLineGradTo: '#e3ecfe',
            thirdLineShadow: 'rgba(14, 16, 48, 0.4)',
        },
        orderProfitLegend: {
            firstItem: '#719efc',
            secondItem: '#5dcfe3',
            thirdItem: '#e3ecfe',
        },
        visitors: {
            tooltipBg: '#ffffff',
            tooltipLineColor: 'rgba(0, 0, 0, 0)',
            tooltipLineWidth: '0',
            tooltipBorderColor: '#ebeef2',
            tooltipExtraCss: 'border-radius: 10px; padding: 8px 24px;',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: 'bolder',
            tooltipFontSize: '20',
            axisLineColor: 'rgba(161, 161 ,229, 0.3)',
            axisFontSize: '16',
            axisTextColor: '#b2bac2',
            yAxisSplitLine: 'rgba(161, 161 ,229, 0.2)',
            itemBorderColor: '#73a1ff',
            lineStyle: 'dotted',
            lineWidth: '6',
            lineGradFrom: '#73a1ff',
            lineGradTo: '#73a1ff',
            lineShadow: 'rgba(0, 0, 0, 0)',
            areaGradFrom: 'rgba(146, 181, 252, 1)',
            areaGradTo: 'rgba(146, 181, 252, 1)',
            shadowLineDarkBg: '#a695ff',
            innerLineStyle: 'solid',
            innerLineWidth: '1',
            innerAreaGradFrom: 'rgba(227, 236, 254, 1)',
            innerAreaGradTo: 'rgba(227, 236, 254, 1)',
        },
        visitorsLegend: {
            firstIcon: '#e3ecfe',
            secondIcon: '#719efc',
        },
        visitorsPie: {
            firstPieGradientLeft: '#94e2ed',
            firstPieGradientRight: '#94e2ed',
            firstPieShadowColor: 'rgba(0, 0, 0, 0)',
            firstPieRadius: ['65%', '90%'],
            secondPieGradientLeft: '#719efc',
            secondPieGradientRight: '#719efc',
            secondPieShadowColor: '#b2cafb',
            secondPieRadius: ['63%', '92%'],
            shadowOffsetX: '-4',
            shadowOffsetY: '-4',
        },
        visitorsPieLegend: {
            firstSection: '#719efc',
            secondSection: '#99e5ee',
        },
        earningPie: {
            radius: ['65%', '100%'],
            center: ['50%', '50%'],
            fontSize: '22',
            firstPieGradientLeft: '#719efc',
            firstPieGradientRight: '#719efc',
            firstPieShadowColor: 'rgba(0, 0, 0, 0)',
            secondPieGradientLeft: '#ff9f6f',
            secondPieGradientRight: '#ff9f6f',
            secondPieShadowColor: 'rgba(0, 0, 0, 0)',
            thirdPieGradientLeft: '#ff5e83',
            thirdPieGradientRight: '#ff5e83',
            thirdPieShadowColor: 'rgba(0, 0, 0, 0)',
        },
        earningLine: {
            gradFrom: '#e3ecfe',
            gradTo: '#e3ecfe',
            tooltipTextColor: '#2a2a2a',
            tooltipFontWeight: '400',
            tooltipFontSize: '16',
            tooltipBg: '#eef2f5',
            tooltipBorderColor: '#eef2f5',
            tooltipBorderWidth: '3',
            tooltipExtraCss: 'border-radius: 10px; padding: 4px 16px;',
        },
    },
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const BASE_MODULES = [CommonModule, FormsModule, ReactiveFormsModule];
/** @type {?} */
const NB_MODULES = [
    NbCardModule,
    NbLayoutModule,
    NbTabsetModule,
    NbRouteTabsetModule,
    NbMenuModule,
    NbUserModule,
    NbActionsModule,
    NbSearchModule,
    NbSidebarModule,
    NbCheckboxModule,
    NbPopoverModule,
    NbContextMenuModule,
    NgbModule,
    NbSecurityModule,
    NbProgressBarModule,
    NbCalendarModule,
    NbCalendarRangeModule,
    NbStepperModule,
    NbButtonModule,
    NbListModule,
    NbToastrModule,
    NbInputModule,
    NbAccordionModule,
    NbDatepickerModule,
    NbDialogModule,
    NbWindowModule,
    NbAlertModule,
    NbSpinnerModule,
    NbRadioModule,
    NbSelectModule,
    NbChatModule,
    NbTooltipModule,
    NbCalendarKitModule,
];
/** @type {?} */
const COMPONENTS = [
    SwitcherComponent,
    LayoutDirectionSwitcherComponent,
    ThemeSwitcherComponent,
    ThemeSwitcherListComponent,
    HeaderComponent,
    FooterComponent,
    SearchInputComponent,
    ThemeSettingsComponent,
    TinyMCEComponent,
    OneColumnLayoutComponent,
    SampleLayoutComponent,
    ThreeColumnsLayoutComponent,
    TwoColumnsLayoutComponent,
    ToggleSettingsButtonComponent,
];
/** @type {?} */
const ENTRY_COMPONENTS = [
    ThemeSwitcherListComponent,
];
/** @type {?} */
const PIPES = [
    CapitalizePipe,
    PluralPipe,
    RoundPipe,
    TimingPipe,
    NumberWithCommasPipe,
    EvaIconsPipe,
];
/** @type {?} */
const NB_THEME_PROVIDERS = [
    ...NbThemeModule.forRoot({
        name: 'cosmic',
    }, [DEFAULT_THEME, COSMIC_THEME, CORPORATE_THEME]).providers,
    ...NbSidebarModule.forRoot().providers,
    ...NbMenuModule.forRoot().providers,
    ...NbDatepickerModule.forRoot().providers,
    ...NbDialogModule.forRoot().providers,
    ...NbWindowModule.forRoot().providers,
    ...NbToastrModule.forRoot().providers,
    ...NbChatModule.forRoot({
        messageGoogleMapKey: 'AIzaSyA_wNuCzia92MAmdLRzmqitRGvCF7wCZPY',
    }).providers,
];
class ThemeModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return (/** @type {?} */ ({
            ngModule: ThemeModule,
            providers: [...NB_THEME_PROVIDERS],
        }));
    }
}
ThemeModule.decorators = [
    { type: NgModule, args: [{
                imports: [...BASE_MODULES, ...NB_MODULES],
                exports: [...BASE_MODULES, ...NB_MODULES, ...COMPONENTS, ...PIPES],
                declarations: [...COMPONENTS, ...PIPES],
                entryComponents: [...ENTRY_COMPONENTS],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const providers = [
    { provide: APP_BASE_HREF, useValue: '/' }
];
class AppModule {
}
AppModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AppComponent],
                imports: [
                    BrowserModule,
                    BrowserAnimationsModule,
                    HttpClientModule,
                    AppRoutingModule,
                    NgbModule.forRoot(),
                    ThemeModule.forRoot(),
                    CoreModule.forRoot(),
                ],
                bootstrap: [AppComponent],
                providers: providers,
                exports: [AppComponent]
            },] }
];
class NgxRootModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AppModule,
            providers: providers
        };
    }
}
NgxRootModule.decorators = [
    { type: NgModule, args: [{},] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxRootModule, CoreModule as ɵbe, NB_CORE_PROVIDERS as ɵbd, NbSimpleRoleProvider as ɵbc, CountryOrderData as ɵcm, EarningData as ɵbw, ElectricityData as ɵbj, OrdersChartData as ɵbq, OrdersProfitChartData as ɵby, ProfitBarAnimationChartData as ɵcc, ProfitChartData as ɵbs, SecurityCamerasData as ɵcs, SmartTableData as ɵbl, SolarData as ɵcg, StatsBarData as ɵck, StatsProgressBarData as ɵco, TemperatureHumidityData as ɵce, TrafficBarData as ɵca, TrafficChartData as ɵci, TrafficListData as ɵbu, UserActivityData as ɵbn, UserData as ɵbh, VisitorsAnalyticsData as ɵcq, CountryOrderService as ɵcl, EarningService as ɵbv, ElectricityService as ɵbi, MockDataModule as ɵbf, OrdersChartService as ɵbp, OrdersProfitChartService as ɵbx, PeriodsService as ɵbo, ProfitBarAnimationChartService as ɵcb, ProfitChartService as ɵbr, SecurityCamerasService as ɵcr, SmartTableService as ɵbk, SolarService as ɵcf, StatsBarService as ɵcj, StatsProgressBarService as ɵcn, TemperatureHumidityService as ɵcd, TrafficBarService as ɵbz, TrafficChartService as ɵch, TrafficListService as ɵbt, UserActivityService as ɵbm, UserService as ɵbg, VisitorsAnalyticsService as ɵcp, AnalyticsService as ɵc, LayoutService as ɵct, PlayerService as ɵcu, StateService as ɵcv, FooterComponent as ɵk, HeaderComponent as ɵj, LayoutDirectionSwitcherComponent as ɵg, SearchInputComponent as ɵl, SwitcherComponent as ɵf, ThemeSettingsComponent as ɵm, ThemeSwitcherComponent as ɵh, ThemeSwitcherListComponent as ɵi, TinyMCEComponent as ɵn, ToggleSettingsButtonComponent as ɵs, OneColumnLayoutComponent as ɵo, SampleLayoutComponent as ɵp, ThreeColumnsLayoutComponent as ɵq, TwoColumnsLayoutComponent as ɵr, CapitalizePipe as ɵt, EvaIconsPipe as ɵy, NumberWithCommasPipe as ɵx, PluralPipe as ɵu, RoundPipe as ɵv, TimingPipe as ɵw, CORPORATE_THEME as ɵbb, COSMIC_THEME as ɵba, DEFAULT_THEME as ɵz, ThemeModule as ɵe, AppRoutingModule as ɵd, AppComponent as ɵb, AppModule as ɵa };

//# sourceMappingURL=john-ngx-t2.js.map